"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: D410, E501, E101, D206
from apimatic_core.authentication.multiple.single_auth import (
    Single,
)
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter

from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.configuration import (
    Server,
)
from mindbodypublicapi.controllers.base_controller import (
    BaseController,
)
from mindbodypublicapi.http.http_method_enum import (
    HttpMethodEnum,
)
from mindbodypublicapi.models.class_schedule import (
    ClassSchedule,
)
from mindbodypublicapi.models.get_enrollments_response import (
    GetEnrollmentsResponse,
)
from mindbodypublicapi.models.written_class_schedules_info import (
    WrittenClassSchedulesInfo,
)


class EnrollmentController(BaseController):
    """A Controller to access Endpoints in the mindbodypublicapi API."""

    def __init__(self, config):
        """Initialize EnrollmentController object."""
        super(EnrollmentController, self).__init__(config)

    def get_enrollments(self,
                        version,
                        site_id,
                        authorization=None,
                        request_class_schedule_ids=None,
                        request_end_date=None,
                        request_limit=None,
                        request_location_ids=None,
                        request_offset=None,
                        request_program_ids=None,
                        request_session_type_ids=None,
                        request_staff_ids=None,
                        request_start_date=None):
        """Perform a GET request to /public/v{version}/enrollment/enrollments.

        Returns a list of enrollments. An enrollment is a service, such as a workshop
        or an event, that a staff member offers to multiple students, who commit to
        coming to all or most of the scheduled sessions. Enrollments typically run
        for a limited time only.

        When a user token is not passed with the request or the passed user token has
        insufficient viewing permissions, only the following staff data is returned
        in the response:

        * FirstName
        * LastName
        * Id
        * Bio
        * DisplayName
        * ImageUrl

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_class_schedule_ids (List[int], optional): A list of the requested
                class schedule IDs. If omitted, all class schedule IDs return.
            request_end_date (datetime, optional): The end of the date range. The
                response returns any active enrollments that occur on or before this
                day.<br />  Default: **StartDate**
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_location_ids (List[int], optional): List of the IDs for the
                requested locations. If omitted, all location IDs return.
            request_offset (int, optional): Page offset, defaults to 0.
            request_program_ids (List[int], optional): List of the IDs for the
                requested programs. If omitted, all program IDs return.
            request_session_type_ids (List[int], optional): List of the IDs for the
                requested session types. If omitted, all session types IDs return.
            request_staff_ids (List[int], optional): List of the IDs for the
                requested staff IDs. If omitted, all staff IDs return.
            request_start_date (datetime, optional): The start of the date range. The
                response returns any active enrollments that occur on or after this
                day.<br />  Default: **today’s date**

        Returns:
            GetEnrollmentsResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/enrollment/enrollments")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.classScheduleIds")
                .value(request_class_schedule_ids))
            .query_param(Parameter()
                .key("request.endDate")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_end_date)))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.locationIds")
                .value(request_location_ids))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.programIds")
                .value(request_program_ids))
            .query_param(Parameter()
                .key("request.sessionTypeIds")
                .value(request_session_type_ids))
            .query_param(Parameter()
                .key("request.staffIds")
                .value(request_staff_ids))
            .query_param(Parameter()
                .key("request.startDate")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_start_date)))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetEnrollmentsResponse.from_dictionary),
        ).execute()

    def add_client_to_enrollment(self,
                                 version,
                                 request,
                                 site_id,
                                 authorization=None):
        """Perform a POST request to
        /public/v{version}/enrollment/addclienttoenrollment.

        Book a client into an enrollment.

        Args:
            version (str): version of the api.
            request (AddClientToEnrollmentRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            ClassSchedule: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/enrollment/addclienttoenrollment")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(ClassSchedule.from_dictionary),
        ).execute()

    def add_enrollment_schedule(self,
                                version,
                                request,
                                site_id,
                                authorization=None):
        """Perform a POST request to
        /public/v{version}/enrollment/addenrollmentschedule.

        This endpoint adds a enrollment schedule. You can require clients to sign up
        for the entire enrollment schedule or allow them to pick specific sessions
        using the AllowOpenEnrollment parameter.

        Args:
            version (str): version of the api.
            request (AddClassEnrollmentScheduleRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            WrittenClassSchedulesInfo: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/enrollment/addenrollmentschedule")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(WrittenClassSchedulesInfo.from_dictionary),
        ).execute()

    def update_enrollment_schedule(self,
                                   version,
                                   request,
                                   site_id,
                                   authorization=None):
        """Perform a POST request to
        /public/v{version}/enrollment/updateenrollmentschedule.

        This endpoint update a enrollment schedule.

        Args:
            version (str): version of the api.
            request (UpdateClassEnrollmentScheduleRequest): The request body
                parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            WrittenClassSchedulesInfo: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/enrollment/updateenrollmentschedule")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(WrittenClassSchedulesInfo.from_dictionary),
        ).execute()



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.add_on_small import (
    AddOnSmall,
)
from mindbodypublicapi.models.appointment_staff import (
    AppointmentStaff,
)
from mindbodypublicapi.models.resource_slim import (
    ResourceSlim,
)


class Appointment(object):
    """Implementation of the 'Appointment' model.

    Contains information about an appointment.

    Attributes:
        gender_preference (GenderPreferenceEnum): The prefered gender of the
            appointment provider.   Possible values are:  * None  * Female  * Male
        duration (int): The duration of the appointment.
        provider_id (str): If a user has Complementary and Alternative Medicine
            features enabled, this property indicates the provider assigned to the
            appointment.
        id (int): The unique ID of the appointment.
        status (StatusEnum): The status of this appointment.  Possible values are:  *
            None  * Requested  * Booked  * Completed  * Confirmed  * Arrived  *
            NoShow  * Cancelled  * LateCancelled
        start_date_time (datetime): The date and time the appointment is to start.
        end_date_time (datetime): The date and time the appointment is to end.
        notes (str): Any notes associated with the appointment.
        partner_external_id (str): Optional external key for api partners.
        staff_requested (bool): When `true`, indicates that the staff member was
            requested specifically by the client.
        program_id (int): The ID of the program to which this appointment belongs.
        session_type_id (int): The ID of the session type of this appointment.
        location_id (int): The ID of the location where this appointment is to take
            place.
        staff_id (int): The ID of the staff member providing the service for this
            appointment.
        staff (AppointmentStaff): The model property of type AppointmentStaff.
        client_id (str): The RSSID of the client who is booked for this appointment.
        first_appointment (bool): When `true`, indicates that this is the client’s
            first appointment at this site.
        is_waitlist (bool): When `true`, indicates that the client should be added to
            a specific appointment waiting list.  When `false`, the client should not
            be added to the waiting list.  Default: *false*
        waitlist_entry_id (int): The unique ID of the appointment waitlist.
        client_service_id (int): The ID of the pass on the client’s account that is
            to pay for this appointment.
        resources (List[ResourceSlim]): The resources this appointment is to use.
        add_ons (List[AddOnSmall]): Any AddOns associated with the appointment
        online_description (str): Online Description associated with the appointment

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "gender_preference": "GenderPreference",
        "duration": "Duration",
        "provider_id": "ProviderId",
        "id": "Id",
        "status": "Status",
        "start_date_time": "StartDateTime",
        "end_date_time": "EndDateTime",
        "notes": "Notes",
        "partner_external_id": "PartnerExternalId",
        "staff_requested": "StaffRequested",
        "program_id": "ProgramId",
        "session_type_id": "SessionTypeId",
        "location_id": "LocationId",
        "staff_id": "StaffId",
        "staff": "Staff",
        "client_id": "ClientId",
        "first_appointment": "FirstAppointment",
        "is_waitlist": "IsWaitlist",
        "waitlist_entry_id": "WaitlistEntryId",
        "client_service_id": "ClientServiceId",
        "resources": "Resources",
        "add_ons": "AddOns",
        "online_description": "OnlineDescription",
    }

    _optionals = [
        "gender_preference",
        "duration",
        "provider_id",
        "id",
        "status",
        "start_date_time",
        "end_date_time",
        "notes",
        "partner_external_id",
        "staff_requested",
        "program_id",
        "session_type_id",
        "location_id",
        "staff_id",
        "staff",
        "client_id",
        "first_appointment",
        "is_waitlist",
        "waitlist_entry_id",
        "client_service_id",
        "resources",
        "add_ons",
        "online_description",
    ]

    def __init__(
        self,
        gender_preference=APIHelper.SKIP,
        duration=APIHelper.SKIP,
        provider_id=APIHelper.SKIP,
        id=APIHelper.SKIP,
        status=APIHelper.SKIP,
        start_date_time=APIHelper.SKIP,
        end_date_time=APIHelper.SKIP,
        notes=APIHelper.SKIP,
        partner_external_id=APIHelper.SKIP,
        staff_requested=APIHelper.SKIP,
        program_id=APIHelper.SKIP,
        session_type_id=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        staff_id=APIHelper.SKIP,
        staff=APIHelper.SKIP,
        client_id=APIHelper.SKIP,
        first_appointment=APIHelper.SKIP,
        is_waitlist=APIHelper.SKIP,
        waitlist_entry_id=APIHelper.SKIP,
        client_service_id=APIHelper.SKIP,
        resources=APIHelper.SKIP,
        add_ons=APIHelper.SKIP,
        online_description=APIHelper.SKIP):
        """Initialize a Appointment instance."""
        # Initialize members of the class
        if gender_preference is not APIHelper.SKIP:
            self.gender_preference = gender_preference
        if duration is not APIHelper.SKIP:
            self.duration = duration
        if provider_id is not APIHelper.SKIP:
            self.provider_id = provider_id
        if id is not APIHelper.SKIP:
            self.id = id
        if status is not APIHelper.SKIP:
            self.status = status
        if start_date_time is not APIHelper.SKIP:
            self.start_date_time =\
                 APIHelper.apply_datetime_converter(
                start_date_time, APIHelper.RFC3339DateTime)\
                 if start_date_time else None
        if end_date_time is not APIHelper.SKIP:
            self.end_date_time =\
                 APIHelper.apply_datetime_converter(
                end_date_time, APIHelper.RFC3339DateTime)\
                 if end_date_time else None
        if notes is not APIHelper.SKIP:
            self.notes = notes
        if partner_external_id is not APIHelper.SKIP:
            self.partner_external_id = partner_external_id
        if staff_requested is not APIHelper.SKIP:
            self.staff_requested = staff_requested
        if program_id is not APIHelper.SKIP:
            self.program_id = program_id
        if session_type_id is not APIHelper.SKIP:
            self.session_type_id = session_type_id
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if staff_id is not APIHelper.SKIP:
            self.staff_id = staff_id
        if staff is not APIHelper.SKIP:
            self.staff = staff
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if first_appointment is not APIHelper.SKIP:
            self.first_appointment = first_appointment
        if is_waitlist is not APIHelper.SKIP:
            self.is_waitlist = is_waitlist
        if waitlist_entry_id is not APIHelper.SKIP:
            self.waitlist_entry_id = waitlist_entry_id
        if client_service_id is not APIHelper.SKIP:
            self.client_service_id = client_service_id
        if resources is not APIHelper.SKIP:
            self.resources = resources
        if add_ons is not APIHelper.SKIP:
            self.add_ons = add_ons
        if online_description is not APIHelper.SKIP:
            self.online_description = online_description

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        gender_preference =\
            dictionary.get("GenderPreference")\
            if dictionary.get("GenderPreference")\
                else APIHelper.SKIP
        duration =\
            dictionary.get("Duration")\
            if dictionary.get("Duration")\
                else APIHelper.SKIP
        provider_id =\
            dictionary.get("ProviderId")\
            if dictionary.get("ProviderId")\
                else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        status =\
            dictionary.get("Status")\
            if dictionary.get("Status")\
                else APIHelper.SKIP
        start_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDateTime")).datetime\
            if dictionary.get("StartDateTime") else APIHelper.SKIP
        end_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDateTime")).datetime\
            if dictionary.get("EndDateTime") else APIHelper.SKIP
        notes =\
            dictionary.get("Notes")\
            if dictionary.get("Notes")\
                else APIHelper.SKIP
        partner_external_id =\
            dictionary.get("PartnerExternalId")\
            if dictionary.get("PartnerExternalId")\
                else APIHelper.SKIP
        staff_requested =\
            dictionary.get("StaffRequested")\
            if "StaffRequested" in dictionary.keys()\
                else APIHelper.SKIP
        program_id =\
            dictionary.get("ProgramId")\
            if dictionary.get("ProgramId")\
                else APIHelper.SKIP
        session_type_id =\
            dictionary.get("SessionTypeId")\
            if dictionary.get("SessionTypeId")\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else APIHelper.SKIP
        staff =\
            AppointmentStaff.from_dictionary(
                dictionary.get("Staff"))\
                if "Staff" in dictionary.keys()\
                else APIHelper.SKIP
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else APIHelper.SKIP
        first_appointment =\
            dictionary.get("FirstAppointment")\
            if "FirstAppointment" in dictionary.keys()\
                else APIHelper.SKIP
        is_waitlist =\
            dictionary.get("IsWaitlist")\
            if "IsWaitlist" in dictionary.keys()\
                else APIHelper.SKIP
        waitlist_entry_id =\
            dictionary.get("WaitlistEntryId")\
            if dictionary.get("WaitlistEntryId")\
                else APIHelper.SKIP
        client_service_id =\
            dictionary.get("ClientServiceId")\
            if dictionary.get("ClientServiceId")\
                else APIHelper.SKIP
        resources = None
        if dictionary.get("Resources") is not None:
            resources = [
                ResourceSlim.from_dictionary(x)
                    for x in dictionary.get("Resources")
            ]
        else:
            resources = APIHelper.SKIP
        add_ons = None
        if dictionary.get("AddOns") is not None:
            add_ons = [
                AddOnSmall.from_dictionary(x)
                    for x in dictionary.get("AddOns")
            ]
        else:
            add_ons = APIHelper.SKIP
        online_description =\
            dictionary.get("OnlineDescription")\
            if dictionary.get("OnlineDescription")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(gender_preference,
                   duration,
                   provider_id,
                   id,
                   status,
                   start_date_time,
                   end_date_time,
                   notes,
                   partner_external_id,
                   staff_requested,
                   program_id,
                   session_type_id,
                   location_id,
                   staff_id,
                   staff,
                   client_id,
                   first_appointment,
                   is_waitlist,
                   waitlist_entry_id,
                   client_service_id,
                   resources,
                   add_ons,
                   online_description)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _gender_preference=(
            self.gender_preference
            if hasattr(self, "gender_preference")
            else None
        )
        _duration=(
            self.duration
            if hasattr(self, "duration")
            else None
        )
        _provider_id=(
            self.provider_id
            if hasattr(self, "provider_id")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _status=(
            self.status
            if hasattr(self, "status")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _notes=(
            self.notes
            if hasattr(self, "notes")
            else None
        )
        _partner_external_id=(
            self.partner_external_id
            if hasattr(self, "partner_external_id")
            else None
        )
        _staff_requested=(
            self.staff_requested
            if hasattr(self, "staff_requested")
            else None
        )
        _program_id=(
            self.program_id
            if hasattr(self, "program_id")
            else None
        )
        _session_type_id=(
            self.session_type_id
            if hasattr(self, "session_type_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _staff=(
            self.staff
            if hasattr(self, "staff")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _first_appointment=(
            self.first_appointment
            if hasattr(self, "first_appointment")
            else None
        )
        _is_waitlist=(
            self.is_waitlist
            if hasattr(self, "is_waitlist")
            else None
        )
        _waitlist_entry_id=(
            self.waitlist_entry_id
            if hasattr(self, "waitlist_entry_id")
            else None
        )
        _client_service_id=(
            self.client_service_id
            if hasattr(self, "client_service_id")
            else None
        )
        _resources=(
            self.resources
            if hasattr(self, "resources")
            else None
        )
        _add_ons=(
            self.add_ons
            if hasattr(self, "add_ons")
            else None
        )
        _online_description=(
            self.online_description
            if hasattr(self, "online_description")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"gender_preference={_gender_preference!r}, "
            f"duration={_duration!r}, "
            f"provider_id={_provider_id!r}, "
            f"id={_id!r}, "
            f"status={_status!r}, "
            f"start_date_time={_start_date_time!r}, "
            f"end_date_time={_end_date_time!r}, "
            f"notes={_notes!r}, "
            f"partner_external_id={_partner_external_id!r}, "
            f"staff_requested={_staff_requested!r}, "
            f"program_id={_program_id!r}, "
            f"session_type_id={_session_type_id!r}, "
            f"location_id={_location_id!r}, "
            f"staff_id={_staff_id!r}, "
            f"staff={_staff!r}, "
            f"client_id={_client_id!r}, "
            f"first_appointment={_first_appointment!r}, "
            f"is_waitlist={_is_waitlist!r}, "
            f"waitlist_entry_id={_waitlist_entry_id!r}, "
            f"client_service_id={_client_service_id!r}, "
            f"resources={_resources!r}, "
            f"add_ons={_add_ons!r}, "
            f"online_description={_online_description!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _gender_preference=(
            self.gender_preference
            if hasattr(self, "gender_preference")
            else None
        )
        _duration=(
            self.duration
            if hasattr(self, "duration")
            else None
        )
        _provider_id=(
            self.provider_id
            if hasattr(self, "provider_id")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _status=(
            self.status
            if hasattr(self, "status")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _notes=(
            self.notes
            if hasattr(self, "notes")
            else None
        )
        _partner_external_id=(
            self.partner_external_id
            if hasattr(self, "partner_external_id")
            else None
        )
        _staff_requested=(
            self.staff_requested
            if hasattr(self, "staff_requested")
            else None
        )
        _program_id=(
            self.program_id
            if hasattr(self, "program_id")
            else None
        )
        _session_type_id=(
            self.session_type_id
            if hasattr(self, "session_type_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _staff=(
            self.staff
            if hasattr(self, "staff")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _first_appointment=(
            self.first_appointment
            if hasattr(self, "first_appointment")
            else None
        )
        _is_waitlist=(
            self.is_waitlist
            if hasattr(self, "is_waitlist")
            else None
        )
        _waitlist_entry_id=(
            self.waitlist_entry_id
            if hasattr(self, "waitlist_entry_id")
            else None
        )
        _client_service_id=(
            self.client_service_id
            if hasattr(self, "client_service_id")
            else None
        )
        _resources=(
            self.resources
            if hasattr(self, "resources")
            else None
        )
        _add_ons=(
            self.add_ons
            if hasattr(self, "add_ons")
            else None
        )
        _online_description=(
            self.online_description
            if hasattr(self, "online_description")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"gender_preference={_gender_preference!s}, "
            f"duration={_duration!s}, "
            f"provider_id={_provider_id!s}, "
            f"id={_id!s}, "
            f"status={_status!s}, "
            f"start_date_time={_start_date_time!s}, "
            f"end_date_time={_end_date_time!s}, "
            f"notes={_notes!s}, "
            f"partner_external_id={_partner_external_id!s}, "
            f"staff_requested={_staff_requested!s}, "
            f"program_id={_program_id!s}, "
            f"session_type_id={_session_type_id!s}, "
            f"location_id={_location_id!s}, "
            f"staff_id={_staff_id!s}, "
            f"staff={_staff!s}, "
            f"client_id={_client_id!s}, "
            f"first_appointment={_first_appointment!s}, "
            f"is_waitlist={_is_waitlist!s}, "
            f"waitlist_entry_id={_waitlist_entry_id!s}, "
            f"client_service_id={_client_service_id!s}, "
            f"resources={_resources!s}, "
            f"add_ons={_add_ons!s}, "
            f"online_description={_online_description!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.payment_processing_failure import (
    PaymentProcessingFailure,
)


class PurchaseGiftCardResponse(object):
    """Implementation of the 'PurchaseGiftCardResponse' model.

    Attributes:
        barcode_id (str): The barcode ID assigned to the purchased gift card.
        value (float): The monetary value of the gift card.
        amount_paid (float): The amount paid for the gift card by the purchaser.
        from_name (str): The name of the purchaser.
        layout_id (int): The ID of the layout used for this gift card.
        email_receipt (bool): Whether or not an email receipt was sent to the
            purchaser. If true, a receipt was sent.
        purchaser_client_id (str): The client ID of the purchaser.
        purchaser_email (str): The purchaser’s email address.
        recipient_email (str): The recipient’s email address.
        sale_id (int): The sale ID of the gift card.
        payment_processing_failures (List[PaymentProcessingFailure]): Any cart
            processing failures, for example when SCA challenged, the cart is in
            PaymentAuthenticationRequired state and at least one of the failures
            listed will provide an authentication Url.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "barcode_id": "BarcodeId",
        "value": "Value",
        "amount_paid": "AmountPaid",
        "from_name": "FromName",
        "layout_id": "LayoutId",
        "email_receipt": "EmailReceipt",
        "purchaser_client_id": "PurchaserClientId",
        "purchaser_email": "PurchaserEmail",
        "recipient_email": "RecipientEmail",
        "sale_id": "SaleId",
        "payment_processing_failures": "PaymentProcessingFailures",
    }

    _optionals = [
        "barcode_id",
        "value",
        "amount_paid",
        "from_name",
        "layout_id",
        "email_receipt",
        "purchaser_client_id",
        "purchaser_email",
        "recipient_email",
        "sale_id",
        "payment_processing_failures",
    ]

    def __init__(
        self,
        barcode_id=APIHelper.SKIP,
        value=APIHelper.SKIP,
        amount_paid=APIHelper.SKIP,
        from_name=APIHelper.SKIP,
        layout_id=APIHelper.SKIP,
        email_receipt=APIHelper.SKIP,
        purchaser_client_id=APIHelper.SKIP,
        purchaser_email=APIHelper.SKIP,
        recipient_email=APIHelper.SKIP,
        sale_id=APIHelper.SKIP,
        payment_processing_failures=APIHelper.SKIP):
        """Initialize a PurchaseGiftCardResponse instance."""
        # Initialize members of the class
        if barcode_id is not APIHelper.SKIP:
            self.barcode_id = barcode_id
        if value is not APIHelper.SKIP:
            self.value = value
        if amount_paid is not APIHelper.SKIP:
            self.amount_paid = amount_paid
        if from_name is not APIHelper.SKIP:
            self.from_name = from_name
        if layout_id is not APIHelper.SKIP:
            self.layout_id = layout_id
        if email_receipt is not APIHelper.SKIP:
            self.email_receipt = email_receipt
        if purchaser_client_id is not APIHelper.SKIP:
            self.purchaser_client_id = purchaser_client_id
        if purchaser_email is not APIHelper.SKIP:
            self.purchaser_email = purchaser_email
        if recipient_email is not APIHelper.SKIP:
            self.recipient_email = recipient_email
        if sale_id is not APIHelper.SKIP:
            self.sale_id = sale_id
        if payment_processing_failures is not APIHelper.SKIP:
            self.payment_processing_failures = payment_processing_failures

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        barcode_id =\
            dictionary.get("BarcodeId")\
            if dictionary.get("BarcodeId")\
                else APIHelper.SKIP
        value =\
            dictionary.get("Value")\
            if dictionary.get("Value")\
                else APIHelper.SKIP
        amount_paid =\
            dictionary.get("AmountPaid")\
            if dictionary.get("AmountPaid")\
                else APIHelper.SKIP
        from_name =\
            dictionary.get("FromName")\
            if dictionary.get("FromName")\
                else APIHelper.SKIP
        layout_id =\
            dictionary.get("LayoutId")\
            if dictionary.get("LayoutId")\
                else APIHelper.SKIP
        email_receipt =\
            dictionary.get("EmailReceipt")\
            if "EmailReceipt" in dictionary.keys()\
                else APIHelper.SKIP
        purchaser_client_id =\
            dictionary.get("PurchaserClientId")\
            if dictionary.get("PurchaserClientId")\
                else APIHelper.SKIP
        purchaser_email =\
            dictionary.get("PurchaserEmail")\
            if dictionary.get("PurchaserEmail")\
                else APIHelper.SKIP
        recipient_email =\
            dictionary.get("RecipientEmail")\
            if dictionary.get("RecipientEmail")\
                else APIHelper.SKIP
        sale_id =\
            dictionary.get("SaleId")\
            if dictionary.get("SaleId")\
                else APIHelper.SKIP
        payment_processing_failures = None
        if dictionary.get("PaymentProcessingFailures") is not None:
            payment_processing_failures = [
                PaymentProcessingFailure.from_dictionary(x)
                    for x in dictionary.get("PaymentProcessingFailures")
            ]
        else:
            payment_processing_failures = APIHelper.SKIP

        # Return an object of this model
        return cls(barcode_id,
                   value,
                   amount_paid,
                   from_name,
                   layout_id,
                   email_receipt,
                   purchaser_client_id,
                   purchaser_email,
                   recipient_email,
                   sale_id,
                   payment_processing_failures)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _barcode_id=(
            self.barcode_id
            if hasattr(self, "barcode_id")
            else None
        )
        _value=(
            self.value
            if hasattr(self, "value")
            else None
        )
        _amount_paid=(
            self.amount_paid
            if hasattr(self, "amount_paid")
            else None
        )
        _from_name=(
            self.from_name
            if hasattr(self, "from_name")
            else None
        )
        _layout_id=(
            self.layout_id
            if hasattr(self, "layout_id")
            else None
        )
        _email_receipt=(
            self.email_receipt
            if hasattr(self, "email_receipt")
            else None
        )
        _purchaser_client_id=(
            self.purchaser_client_id
            if hasattr(self, "purchaser_client_id")
            else None
        )
        _purchaser_email=(
            self.purchaser_email
            if hasattr(self, "purchaser_email")
            else None
        )
        _recipient_email=(
            self.recipient_email
            if hasattr(self, "recipient_email")
            else None
        )
        _sale_id=(
            self.sale_id
            if hasattr(self, "sale_id")
            else None
        )
        _payment_processing_failures=(
            self.payment_processing_failures
            if hasattr(self, "payment_processing_failures")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"barcode_id={_barcode_id!r}, "
            f"value={_value!r}, "
            f"amount_paid={_amount_paid!r}, "
            f"from_name={_from_name!r}, "
            f"layout_id={_layout_id!r}, "
            f"email_receipt={_email_receipt!r}, "
            f"purchaser_client_id={_purchaser_client_id!r}, "
            f"purchaser_email={_purchaser_email!r}, "
            f"recipient_email={_recipient_email!r}, "
            f"sale_id={_sale_id!r}, "
            f"payment_processing_failures={_payment_processing_failures!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _barcode_id=(
            self.barcode_id
            if hasattr(self, "barcode_id")
            else None
        )
        _value=(
            self.value
            if hasattr(self, "value")
            else None
        )
        _amount_paid=(
            self.amount_paid
            if hasattr(self, "amount_paid")
            else None
        )
        _from_name=(
            self.from_name
            if hasattr(self, "from_name")
            else None
        )
        _layout_id=(
            self.layout_id
            if hasattr(self, "layout_id")
            else None
        )
        _email_receipt=(
            self.email_receipt
            if hasattr(self, "email_receipt")
            else None
        )
        _purchaser_client_id=(
            self.purchaser_client_id
            if hasattr(self, "purchaser_client_id")
            else None
        )
        _purchaser_email=(
            self.purchaser_email
            if hasattr(self, "purchaser_email")
            else None
        )
        _recipient_email=(
            self.recipient_email
            if hasattr(self, "recipient_email")
            else None
        )
        _sale_id=(
            self.sale_id
            if hasattr(self, "sale_id")
            else None
        )
        _payment_processing_failures=(
            self.payment_processing_failures
            if hasattr(self, "payment_processing_failures")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"barcode_id={_barcode_id!s}, "
            f"value={_value!s}, "
            f"amount_paid={_amount_paid!s}, "
            f"from_name={_from_name!s}, "
            f"layout_id={_layout_id!s}, "
            f"email_receipt={_email_receipt!s}, "
            f"purchaser_client_id={_purchaser_client_id!s}, "
            f"purchaser_email={_purchaser_email!s}, "
            f"recipient_email={_recipient_email!s}, "
            f"sale_id={_sale_id!s}, "
            f"payment_processing_failures={_payment_processing_failures!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.add_contact_log_type import (
    AddContactLogType,
)


class AddContactLogRequest(object):
    """Implementation of the 'AddContactLogRequest' model.

    Attributes:
        client_id (str): The ID of the client whose contact log is being added.
        assigned_to_staff_id (int): The ID of the staff member to whom the contact
            log is assigned.
        text (str): The body of the contact log.
        followup_by_date (datetime): The date by which the assigned staff member
            should complete this contact log.
        contact_method (str): How the client wants to be contacted.
        contact_name (str): The name of the person to be contacted by the assigned
            staff member.
        is_complete (bool): When `true`, indicates that the contact log is complete.
            When `false`, indicates the contact log isn’t complete.
        comments (List[str]): Any comments on the contact log.
        types (List[AddContactLogType]): The contact log types used to tag this
            contact log.
        test (bool): When `true`, indicates that this is a test request and no data
            is inserted into the subscriber’s database.<br />  When `false`, the
            database is updated.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "contact_method": "ContactMethod",
        "assigned_to_staff_id": "AssignedToStaffId",
        "text": "Text",
        "followup_by_date": "FollowupByDate",
        "contact_name": "ContactName",
        "is_complete": "IsComplete",
        "comments": "Comments",
        "types": "Types",
        "test": "Test",
    }

    _optionals = [
        "assigned_to_staff_id",
        "text",
        "followup_by_date",
        "contact_name",
        "is_complete",
        "comments",
        "types",
        "test",
    ]

    def __init__(
        self,
        client_id=None,
        contact_method=None,
        assigned_to_staff_id=APIHelper.SKIP,
        text=APIHelper.SKIP,
        followup_by_date=APIHelper.SKIP,
        contact_name=APIHelper.SKIP,
        is_complete=APIHelper.SKIP,
        comments=APIHelper.SKIP,
        types=APIHelper.SKIP,
        test=APIHelper.SKIP):
        """Initialize a AddContactLogRequest instance."""
        # Initialize members of the class
        self.client_id = client_id
        if assigned_to_staff_id is not APIHelper.SKIP:
            self.assigned_to_staff_id = assigned_to_staff_id
        if text is not APIHelper.SKIP:
            self.text = text
        if followup_by_date is not APIHelper.SKIP:
            self.followup_by_date =\
                 APIHelper.apply_datetime_converter(
                followup_by_date, APIHelper.RFC3339DateTime)\
                 if followup_by_date else None
        self.contact_method = contact_method
        if contact_name is not APIHelper.SKIP:
            self.contact_name = contact_name
        if is_complete is not APIHelper.SKIP:
            self.is_complete = is_complete
        if comments is not APIHelper.SKIP:
            self.comments = comments
        if types is not APIHelper.SKIP:
            self.types = types
        if test is not APIHelper.SKIP:
            self.test = test

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else None
        contact_method =\
            dictionary.get("ContactMethod")\
            if dictionary.get("ContactMethod")\
                else None
        assigned_to_staff_id =\
            dictionary.get("AssignedToStaffId")\
            if dictionary.get("AssignedToStaffId")\
                else APIHelper.SKIP
        text =\
            dictionary.get("Text")\
            if dictionary.get("Text")\
                else APIHelper.SKIP
        followup_by_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("FollowupByDate")).datetime\
            if dictionary.get("FollowupByDate") else APIHelper.SKIP
        contact_name =\
            dictionary.get("ContactName")\
            if dictionary.get("ContactName")\
                else APIHelper.SKIP
        is_complete =\
            dictionary.get("IsComplete")\
            if "IsComplete" in dictionary.keys()\
                else APIHelper.SKIP
        comments =\
            dictionary.get("Comments")\
            if dictionary.get("Comments")\
                else APIHelper.SKIP
        types = None
        if dictionary.get("Types") is not None:
            types = [
                AddContactLogType.from_dictionary(x)
                    for x in dictionary.get("Types")
            ]
        else:
            types = APIHelper.SKIP
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   contact_method,
                   assigned_to_staff_id,
                   text,
                   followup_by_date,
                   contact_name,
                   is_complete,
                   comments,
                   types,
                   test)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_id=self.client_id
        _assigned_to_staff_id=(
            self.assigned_to_staff_id
            if hasattr(self, "assigned_to_staff_id")
            else None
        )
        _text=(
            self.text
            if hasattr(self, "text")
            else None
        )
        _followup_by_date=(
            self.followup_by_date
            if hasattr(self, "followup_by_date")
            else None
        )
        _contact_method=self.contact_method
        _contact_name=(
            self.contact_name
            if hasattr(self, "contact_name")
            else None
        )
        _is_complete=(
            self.is_complete
            if hasattr(self, "is_complete")
            else None
        )
        _comments=(
            self.comments
            if hasattr(self, "comments")
            else None
        )
        _types=(
            self.types
            if hasattr(self, "types")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!r}, "
            f"assigned_to_staff_id={_assigned_to_staff_id!r}, "
            f"text={_text!r}, "
            f"followup_by_date={_followup_by_date!r}, "
            f"contact_method={_contact_method!r}, "
            f"contact_name={_contact_name!r}, "
            f"is_complete={_is_complete!r}, "
            f"comments={_comments!r}, "
            f"types={_types!r}, "
            f"test={_test!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_id=self.client_id
        _assigned_to_staff_id=(
            self.assigned_to_staff_id
            if hasattr(self, "assigned_to_staff_id")
            else None
        )
        _text=(
            self.text
            if hasattr(self, "text")
            else None
        )
        _followup_by_date=(
            self.followup_by_date
            if hasattr(self, "followup_by_date")
            else None
        )
        _contact_method=self.contact_method
        _contact_name=(
            self.contact_name
            if hasattr(self, "contact_name")
            else None
        )
        _is_complete=(
            self.is_complete
            if hasattr(self, "is_complete")
            else None
        )
        _comments=(
            self.comments
            if hasattr(self, "comments")
            else None
        )
        _types=(
            self.types
            if hasattr(self, "types")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!s}, "
            f"assigned_to_staff_id={_assigned_to_staff_id!s}, "
            f"text={_text!s}, "
            f"followup_by_date={_followup_by_date!s}, "
            f"contact_method={_contact_method!s}, "
            f"contact_name={_contact_name!s}, "
            f"is_complete={_is_complete!s}, "
            f"comments={_comments!s}, "
            f"types={_types!s}, "
            f"test={_test!s}, "
            f")"
        )




"""
mindbodypublicapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from apimatic_core.http.http_callback import HttpCallBack as CoreHttpCallback


class HttpCallBack(CoreHttpCallback):
    """
    An interface for the callback to be called before and after the
    HTTP call for an endpoint is made.

    This class should not be instantiated but should be used as a base class
    for HttpCallBack classes.

    """



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.appointment import (
    Appointment,
)
from mindbodypublicapi.models.availability import (
    Availability,
)
from mindbodypublicapi.models.staff_setting import (
    StaffSetting,
)
from mindbodypublicapi.models.unavailability import (
    Unavailability,
)


class Staff(object):
    """Implementation of the 'Staff' model.

    The Staff

    Attributes:
        address (str): The address of the staff member who is teaching the class.
        appointment_instructor (bool): When `true`, indicates that the staff member
            offers appointments.<br />  When `false`, indicates that the staff member
            does not offer appointments.
        always_allow_double_booking (bool): When `true`, indicates that the staff
            member can be scheduled for overlapping services.<br />  When `false`,
            indicates that the staff can only be scheduled for one service at a time
            in any given time-frame.
        bio (str): The staff member’s biography. This string contains HTML.
        city (str): The staff member’s city.
        country (str): The staff member’s country.
        email (str): The staff member’s email address.
        first_name (str): The staff member’s first name.
        display_name (str): The staff member’s Nickname.
        home_phone (str): The staff member’s home phone number.
        id (int): The ID assigned to the staff member.
        independent_contractor (bool): When `true`, indicates that the staff member
            is an independent contractor.  When `false`, indicates that the staff
            member is not an independent contractor.
        is_male (bool): When `true`, indicates that the staff member is male.  When
            `false`, indicates that the staff member is female.
        last_name (str): The staff member’s last name.
        mobile_phone (str): The staff member’s mobile phone number.
        name (str): The staff member’s name.
        postal_code (str): The staff member’s postal code.
        class_teacher (bool): When `true`, indicates that the staff member can teach
            classes.  When `false`, indicates that the staff member cannot teach
            classes.
        sort_order (int): If configured by the business owner, this field determines
            a staff member’s weight when sorting. Use this field to sort staff
            members on your interface.
        state (str): The staff member’s state.
        work_phone (str): The staff member’s work phone number.
        image_url (str): The URL of the staff member’s image, if one has been
            uploaded.
        class_assistant (bool): Is the staff an assistant
        class_assistant_2 (bool): Is the staff an assistant2
        employment_start (datetime): The start date of employment
        employment_end (datetime): The end date of employment
        provider_i_ds (List[str]): A list of ProviderIds for the staff.
        rep (bool): return true if staff is sales Rep 1 else false.
        rep_2 (bool): return true if staff is sales Rep 2 else false.
        rep_3 (bool): return true if staff is sales Rep 3 else false.
        rep_4 (bool): return true if staff is sales Rep 4 else false.
        rep_5 (bool): return true if staff is sales Rep 5 else false.
        rep_6 (bool): return true if staff is sales Rep 6 else false.
        staff_settings (StaffSetting): contains the information about the staff
            settings.
        appointments (List[Appointment]): A list of appointments for the staff.
        unavailabilities (List[Unavailability]): A list of unavailabilities for the
            staff.
        availabilities (List[Availability]): A list of availabilities for the staff.
        emp_id (str): The EmpID assigned to the staff member.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "address": "Address",
        "appointment_instructor": "AppointmentInstructor",
        "always_allow_double_booking": "AlwaysAllowDoubleBooking",
        "bio": "Bio",
        "city": "City",
        "country": "Country",
        "email": "Email",
        "first_name": "FirstName",
        "display_name": "DisplayName",
        "home_phone": "HomePhone",
        "id": "Id",
        "independent_contractor": "IndependentContractor",
        "is_male": "IsMale",
        "last_name": "LastName",
        "mobile_phone": "MobilePhone",
        "name": "Name",
        "postal_code": "PostalCode",
        "class_teacher": "ClassTeacher",
        "sort_order": "SortOrder",
        "state": "State",
        "work_phone": "WorkPhone",
        "image_url": "ImageUrl",
        "class_assistant": "ClassAssistant",
        "class_assistant_2": "ClassAssistant2",
        "employment_start": "EmploymentStart",
        "employment_end": "EmploymentEnd",
        "provider_i_ds": "ProviderIDs",
        "rep": "Rep",
        "rep_2": "Rep2",
        "rep_3": "Rep3",
        "rep_4": "Rep4",
        "rep_5": "Rep5",
        "rep_6": "Rep6",
        "staff_settings": "StaffSettings",
        "appointments": "Appointments",
        "unavailabilities": "Unavailabilities",
        "availabilities": "Availabilities",
        "emp_id": "EmpID",
    }

    _optionals = [
        "address",
        "appointment_instructor",
        "always_allow_double_booking",
        "bio",
        "city",
        "country",
        "email",
        "first_name",
        "display_name",
        "home_phone",
        "id",
        "independent_contractor",
        "is_male",
        "last_name",
        "mobile_phone",
        "name",
        "postal_code",
        "class_teacher",
        "sort_order",
        "state",
        "work_phone",
        "image_url",
        "class_assistant",
        "class_assistant_2",
        "employment_start",
        "employment_end",
        "provider_i_ds",
        "rep",
        "rep_2",
        "rep_3",
        "rep_4",
        "rep_5",
        "rep_6",
        "staff_settings",
        "appointments",
        "unavailabilities",
        "availabilities",
        "emp_id",
    ]

    def __init__(
        self,
        address=APIHelper.SKIP,
        appointment_instructor=APIHelper.SKIP,
        always_allow_double_booking=APIHelper.SKIP,
        bio=APIHelper.SKIP,
        city=APIHelper.SKIP,
        country=APIHelper.SKIP,
        email=APIHelper.SKIP,
        first_name=APIHelper.SKIP,
        display_name=APIHelper.SKIP,
        home_phone=APIHelper.SKIP,
        id=APIHelper.SKIP,
        independent_contractor=APIHelper.SKIP,
        is_male=APIHelper.SKIP,
        last_name=APIHelper.SKIP,
        mobile_phone=APIHelper.SKIP,
        name=APIHelper.SKIP,
        postal_code=APIHelper.SKIP,
        class_teacher=APIHelper.SKIP,
        sort_order=APIHelper.SKIP,
        state=APIHelper.SKIP,
        work_phone=APIHelper.SKIP,
        image_url=APIHelper.SKIP,
        class_assistant=APIHelper.SKIP,
        class_assistant_2=APIHelper.SKIP,
        employment_start=APIHelper.SKIP,
        employment_end=APIHelper.SKIP,
        provider_i_ds=APIHelper.SKIP,
        rep=APIHelper.SKIP,
        rep_2=APIHelper.SKIP,
        rep_3=APIHelper.SKIP,
        rep_4=APIHelper.SKIP,
        rep_5=APIHelper.SKIP,
        rep_6=APIHelper.SKIP,
        staff_settings=APIHelper.SKIP,
        appointments=APIHelper.SKIP,
        unavailabilities=APIHelper.SKIP,
        availabilities=APIHelper.SKIP,
        emp_id=APIHelper.SKIP):
        """Initialize a Staff instance."""
        # Initialize members of the class
        if address is not APIHelper.SKIP:
            self.address = address
        if appointment_instructor is not APIHelper.SKIP:
            self.appointment_instructor = appointment_instructor
        if always_allow_double_booking is not APIHelper.SKIP:
            self.always_allow_double_booking = always_allow_double_booking
        if bio is not APIHelper.SKIP:
            self.bio = bio
        if city is not APIHelper.SKIP:
            self.city = city
        if country is not APIHelper.SKIP:
            self.country = country
        if email is not APIHelper.SKIP:
            self.email = email
        if first_name is not APIHelper.SKIP:
            self.first_name = first_name
        if display_name is not APIHelper.SKIP:
            self.display_name = display_name
        if home_phone is not APIHelper.SKIP:
            self.home_phone = home_phone
        if id is not APIHelper.SKIP:
            self.id = id
        if independent_contractor is not APIHelper.SKIP:
            self.independent_contractor = independent_contractor
        if is_male is not APIHelper.SKIP:
            self.is_male = is_male
        if last_name is not APIHelper.SKIP:
            self.last_name = last_name
        if mobile_phone is not APIHelper.SKIP:
            self.mobile_phone = mobile_phone
        if name is not APIHelper.SKIP:
            self.name = name
        if postal_code is not APIHelper.SKIP:
            self.postal_code = postal_code
        if class_teacher is not APIHelper.SKIP:
            self.class_teacher = class_teacher
        if sort_order is not APIHelper.SKIP:
            self.sort_order = sort_order
        if state is not APIHelper.SKIP:
            self.state = state
        if work_phone is not APIHelper.SKIP:
            self.work_phone = work_phone
        if image_url is not APIHelper.SKIP:
            self.image_url = image_url
        if class_assistant is not APIHelper.SKIP:
            self.class_assistant = class_assistant
        if class_assistant_2 is not APIHelper.SKIP:
            self.class_assistant_2 = class_assistant_2
        if employment_start is not APIHelper.SKIP:
            self.employment_start =\
                 APIHelper.apply_datetime_converter(
                employment_start, APIHelper.RFC3339DateTime)\
                 if employment_start else None
        if employment_end is not APIHelper.SKIP:
            self.employment_end =\
                 APIHelper.apply_datetime_converter(
                employment_end, APIHelper.RFC3339DateTime)\
                 if employment_end else None
        if provider_i_ds is not APIHelper.SKIP:
            self.provider_i_ds = provider_i_ds
        if rep is not APIHelper.SKIP:
            self.rep = rep
        if rep_2 is not APIHelper.SKIP:
            self.rep_2 = rep_2
        if rep_3 is not APIHelper.SKIP:
            self.rep_3 = rep_3
        if rep_4 is not APIHelper.SKIP:
            self.rep_4 = rep_4
        if rep_5 is not APIHelper.SKIP:
            self.rep_5 = rep_5
        if rep_6 is not APIHelper.SKIP:
            self.rep_6 = rep_6
        if staff_settings is not APIHelper.SKIP:
            self.staff_settings = staff_settings
        if appointments is not APIHelper.SKIP:
            self.appointments = appointments
        if unavailabilities is not APIHelper.SKIP:
            self.unavailabilities = unavailabilities
        if availabilities is not APIHelper.SKIP:
            self.availabilities = availabilities
        if emp_id is not APIHelper.SKIP:
            self.emp_id = emp_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        address =\
            dictionary.get("Address")\
            if dictionary.get("Address")\
                else APIHelper.SKIP
        appointment_instructor =\
            dictionary.get("AppointmentInstructor")\
            if "AppointmentInstructor" in dictionary.keys()\
                else APIHelper.SKIP
        always_allow_double_booking =\
            dictionary.get("AlwaysAllowDoubleBooking")\
            if "AlwaysAllowDoubleBooking" in dictionary.keys()\
                else APIHelper.SKIP
        bio =\
            dictionary.get("Bio")\
            if dictionary.get("Bio")\
                else APIHelper.SKIP
        city =\
            dictionary.get("City")\
            if dictionary.get("City")\
                else APIHelper.SKIP
        country =\
            dictionary.get("Country")\
            if dictionary.get("Country")\
                else APIHelper.SKIP
        email =\
            dictionary.get("Email")\
            if dictionary.get("Email")\
                else APIHelper.SKIP
        first_name =\
            dictionary.get("FirstName")\
            if dictionary.get("FirstName")\
                else APIHelper.SKIP
        display_name =\
            dictionary.get("DisplayName")\
            if dictionary.get("DisplayName")\
                else APIHelper.SKIP
        home_phone =\
            dictionary.get("HomePhone")\
            if dictionary.get("HomePhone")\
                else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        independent_contractor =\
            dictionary.get("IndependentContractor")\
            if "IndependentContractor" in dictionary.keys()\
                else APIHelper.SKIP
        is_male =\
            dictionary.get("IsMale")\
            if "IsMale" in dictionary.keys()\
                else APIHelper.SKIP
        last_name =\
            dictionary.get("LastName")\
            if dictionary.get("LastName")\
                else APIHelper.SKIP
        mobile_phone =\
            dictionary.get("MobilePhone")\
            if dictionary.get("MobilePhone")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        postal_code =\
            dictionary.get("PostalCode")\
            if dictionary.get("PostalCode")\
                else APIHelper.SKIP
        class_teacher =\
            dictionary.get("ClassTeacher")\
            if "ClassTeacher" in dictionary.keys()\
                else APIHelper.SKIP
        sort_order =\
            dictionary.get("SortOrder")\
            if dictionary.get("SortOrder")\
                else APIHelper.SKIP
        state =\
            dictionary.get("State")\
            if dictionary.get("State")\
                else APIHelper.SKIP
        work_phone =\
            dictionary.get("WorkPhone")\
            if dictionary.get("WorkPhone")\
                else APIHelper.SKIP
        image_url =\
            dictionary.get("ImageUrl")\
            if dictionary.get("ImageUrl")\
                else APIHelper.SKIP
        class_assistant =\
            dictionary.get("ClassAssistant")\
            if "ClassAssistant" in dictionary.keys()\
                else APIHelper.SKIP
        class_assistant_2 =\
            dictionary.get("ClassAssistant2")\
            if "ClassAssistant2" in dictionary.keys()\
                else APIHelper.SKIP
        employment_start = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EmploymentStart")).datetime\
            if dictionary.get("EmploymentStart") else APIHelper.SKIP
        employment_end = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EmploymentEnd")).datetime\
            if dictionary.get("EmploymentEnd") else APIHelper.SKIP
        provider_i_ds =\
            dictionary.get("ProviderIDs")\
            if dictionary.get("ProviderIDs")\
                else APIHelper.SKIP
        rep =\
            dictionary.get("Rep")\
            if "Rep" in dictionary.keys()\
                else APIHelper.SKIP
        rep_2 =\
            dictionary.get("Rep2")\
            if "Rep2" in dictionary.keys()\
                else APIHelper.SKIP
        rep_3 =\
            dictionary.get("Rep3")\
            if "Rep3" in dictionary.keys()\
                else APIHelper.SKIP
        rep_4 =\
            dictionary.get("Rep4")\
            if "Rep4" in dictionary.keys()\
                else APIHelper.SKIP
        rep_5 =\
            dictionary.get("Rep5")\
            if "Rep5" in dictionary.keys()\
                else APIHelper.SKIP
        rep_6 =\
            dictionary.get("Rep6")\
            if "Rep6" in dictionary.keys()\
                else APIHelper.SKIP
        staff_settings =\
            StaffSetting.from_dictionary(
                dictionary.get("StaffSettings"))\
                if "StaffSettings" in dictionary.keys()\
                else APIHelper.SKIP
        appointments = None
        if dictionary.get("Appointments") is not None:
            appointments = [
                Appointment.from_dictionary(x)
                    for x in dictionary.get("Appointments")
            ]
        else:
            appointments = APIHelper.SKIP
        unavailabilities = None
        if dictionary.get("Unavailabilities") is not None:
            unavailabilities = [
                Unavailability.from_dictionary(x)
                    for x in dictionary.get("Unavailabilities")
            ]
        else:
            unavailabilities = APIHelper.SKIP
        availabilities = None
        if dictionary.get("Availabilities") is not None:
            availabilities = [
                Availability.from_dictionary(x)
                    for x in dictionary.get("Availabilities")
            ]
        else:
            availabilities = APIHelper.SKIP
        emp_id =\
            dictionary.get("EmpID")\
            if dictionary.get("EmpID")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(address,
                   appointment_instructor,
                   always_allow_double_booking,
                   bio,
                   city,
                   country,
                   email,
                   first_name,
                   display_name,
                   home_phone,
                   id,
                   independent_contractor,
                   is_male,
                   last_name,
                   mobile_phone,
                   name,
                   postal_code,
                   class_teacher,
                   sort_order,
                   state,
                   work_phone,
                   image_url,
                   class_assistant,
                   class_assistant_2,
                   employment_start,
                   employment_end,
                   provider_i_ds,
                   rep,
                   rep_2,
                   rep_3,
                   rep_4,
                   rep_5,
                   rep_6,
                   staff_settings,
                   appointments,
                   unavailabilities,
                   availabilities,
                   emp_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _address=(
            self.address
            if hasattr(self, "address")
            else None
        )
        _appointment_instructor=(
            self.appointment_instructor
            if hasattr(self, "appointment_instructor")
            else None
        )
        _always_allow_double_booking=(
            self.always_allow_double_booking
            if hasattr(self, "always_allow_double_booking")
            else None
        )
        _bio=(
            self.bio
            if hasattr(self, "bio")
            else None
        )
        _city=(
            self.city
            if hasattr(self, "city")
            else None
        )
        _country=(
            self.country
            if hasattr(self, "country")
            else None
        )
        _email=(
            self.email
            if hasattr(self, "email")
            else None
        )
        _first_name=(
            self.first_name
            if hasattr(self, "first_name")
            else None
        )
        _display_name=(
            self.display_name
            if hasattr(self, "display_name")
            else None
        )
        _home_phone=(
            self.home_phone
            if hasattr(self, "home_phone")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _independent_contractor=(
            self.independent_contractor
            if hasattr(self, "independent_contractor")
            else None
        )
        _is_male=(
            self.is_male
            if hasattr(self, "is_male")
            else None
        )
        _last_name=(
            self.last_name
            if hasattr(self, "last_name")
            else None
        )
        _mobile_phone=(
            self.mobile_phone
            if hasattr(self, "mobile_phone")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _postal_code=(
            self.postal_code
            if hasattr(self, "postal_code")
            else None
        )
        _class_teacher=(
            self.class_teacher
            if hasattr(self, "class_teacher")
            else None
        )
        _sort_order=(
            self.sort_order
            if hasattr(self, "sort_order")
            else None
        )
        _state=(
            self.state
            if hasattr(self, "state")
            else None
        )
        _work_phone=(
            self.work_phone
            if hasattr(self, "work_phone")
            else None
        )
        _image_url=(
            self.image_url
            if hasattr(self, "image_url")
            else None
        )
        _class_assistant=(
            self.class_assistant
            if hasattr(self, "class_assistant")
            else None
        )
        _class_assistant_2=(
            self.class_assistant_2
            if hasattr(self, "class_assistant_2")
            else None
        )
        _employment_start=(
            self.employment_start
            if hasattr(self, "employment_start")
            else None
        )
        _employment_end=(
            self.employment_end
            if hasattr(self, "employment_end")
            else None
        )
        _provider_i_ds=(
            self.provider_i_ds
            if hasattr(self, "provider_i_ds")
            else None
        )
        _rep=(
            self.rep
            if hasattr(self, "rep")
            else None
        )
        _rep_2=(
            self.rep_2
            if hasattr(self, "rep_2")
            else None
        )
        _rep_3=(
            self.rep_3
            if hasattr(self, "rep_3")
            else None
        )
        _rep_4=(
            self.rep_4
            if hasattr(self, "rep_4")
            else None
        )
        _rep_5=(
            self.rep_5
            if hasattr(self, "rep_5")
            else None
        )
        _rep_6=(
            self.rep_6
            if hasattr(self, "rep_6")
            else None
        )
        _staff_settings=(
            self.staff_settings
            if hasattr(self, "staff_settings")
            else None
        )
        _appointments=(
            self.appointments
            if hasattr(self, "appointments")
            else None
        )
        _unavailabilities=(
            self.unavailabilities
            if hasattr(self, "unavailabilities")
            else None
        )
        _availabilities=(
            self.availabilities
            if hasattr(self, "availabilities")
            else None
        )
        _emp_id=(
            self.emp_id
            if hasattr(self, "emp_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"address={_address!r}, "
            f"appointment_instructor={_appointment_instructor!r}, "
            f"always_allow_double_booking={_always_allow_double_booking!r}, "
            f"bio={_bio!r}, "
            f"city={_city!r}, "
            f"country={_country!r}, "
            f"email={_email!r}, "
            f"first_name={_first_name!r}, "
            f"display_name={_display_name!r}, "
            f"home_phone={_home_phone!r}, "
            f"id={_id!r}, "
            f"independent_contractor={_independent_contractor!r}, "
            f"is_male={_is_male!r}, "
            f"last_name={_last_name!r}, "
            f"mobile_phone={_mobile_phone!r}, "
            f"name={_name!r}, "
            f"postal_code={_postal_code!r}, "
            f"class_teacher={_class_teacher!r}, "
            f"sort_order={_sort_order!r}, "
            f"state={_state!r}, "
            f"work_phone={_work_phone!r}, "
            f"image_url={_image_url!r}, "
            f"class_assistant={_class_assistant!r}, "
            f"class_assistant_2={_class_assistant_2!r}, "
            f"employment_start={_employment_start!r}, "
            f"employment_end={_employment_end!r}, "
            f"provider_i_ds={_provider_i_ds!r}, "
            f"rep={_rep!r}, "
            f"rep_2={_rep_2!r}, "
            f"rep_3={_rep_3!r}, "
            f"rep_4={_rep_4!r}, "
            f"rep_5={_rep_5!r}, "
            f"rep_6={_rep_6!r}, "
            f"staff_settings={_staff_settings!r}, "
            f"appointments={_appointments!r}, "
            f"unavailabilities={_unavailabilities!r}, "
            f"availabilities={_availabilities!r}, "
            f"emp_id={_emp_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _address=(
            self.address
            if hasattr(self, "address")
            else None
        )
        _appointment_instructor=(
            self.appointment_instructor
            if hasattr(self, "appointment_instructor")
            else None
        )
        _always_allow_double_booking=(
            self.always_allow_double_booking
            if hasattr(self, "always_allow_double_booking")
            else None
        )
        _bio=(
            self.bio
            if hasattr(self, "bio")
            else None
        )
        _city=(
            self.city
            if hasattr(self, "city")
            else None
        )
        _country=(
            self.country
            if hasattr(self, "country")
            else None
        )
        _email=(
            self.email
            if hasattr(self, "email")
            else None
        )
        _first_name=(
            self.first_name
            if hasattr(self, "first_name")
            else None
        )
        _display_name=(
            self.display_name
            if hasattr(self, "display_name")
            else None
        )
        _home_phone=(
            self.home_phone
            if hasattr(self, "home_phone")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _independent_contractor=(
            self.independent_contractor
            if hasattr(self, "independent_contractor")
            else None
        )
        _is_male=(
            self.is_male
            if hasattr(self, "is_male")
            else None
        )
        _last_name=(
            self.last_name
            if hasattr(self, "last_name")
            else None
        )
        _mobile_phone=(
            self.mobile_phone
            if hasattr(self, "mobile_phone")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _postal_code=(
            self.postal_code
            if hasattr(self, "postal_code")
            else None
        )
        _class_teacher=(
            self.class_teacher
            if hasattr(self, "class_teacher")
            else None
        )
        _sort_order=(
            self.sort_order
            if hasattr(self, "sort_order")
            else None
        )
        _state=(
            self.state
            if hasattr(self, "state")
            else None
        )
        _work_phone=(
            self.work_phone
            if hasattr(self, "work_phone")
            else None
        )
        _image_url=(
            self.image_url
            if hasattr(self, "image_url")
            else None
        )
        _class_assistant=(
            self.class_assistant
            if hasattr(self, "class_assistant")
            else None
        )
        _class_assistant_2=(
            self.class_assistant_2
            if hasattr(self, "class_assistant_2")
            else None
        )
        _employment_start=(
            self.employment_start
            if hasattr(self, "employment_start")
            else None
        )
        _employment_end=(
            self.employment_end
            if hasattr(self, "employment_end")
            else None
        )
        _provider_i_ds=(
            self.provider_i_ds
            if hasattr(self, "provider_i_ds")
            else None
        )
        _rep=(
            self.rep
            if hasattr(self, "rep")
            else None
        )
        _rep_2=(
            self.rep_2
            if hasattr(self, "rep_2")
            else None
        )
        _rep_3=(
            self.rep_3
            if hasattr(self, "rep_3")
            else None
        )
        _rep_4=(
            self.rep_4
            if hasattr(self, "rep_4")
            else None
        )
        _rep_5=(
            self.rep_5
            if hasattr(self, "rep_5")
            else None
        )
        _rep_6=(
            self.rep_6
            if hasattr(self, "rep_6")
            else None
        )
        _staff_settings=(
            self.staff_settings
            if hasattr(self, "staff_settings")
            else None
        )
        _appointments=(
            self.appointments
            if hasattr(self, "appointments")
            else None
        )
        _unavailabilities=(
            self.unavailabilities
            if hasattr(self, "unavailabilities")
            else None
        )
        _availabilities=(
            self.availabilities
            if hasattr(self, "availabilities")
            else None
        )
        _emp_id=(
            self.emp_id
            if hasattr(self, "emp_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"address={_address!s}, "
            f"appointment_instructor={_appointment_instructor!s}, "
            f"always_allow_double_booking={_always_allow_double_booking!s}, "
            f"bio={_bio!s}, "
            f"city={_city!s}, "
            f"country={_country!s}, "
            f"email={_email!s}, "
            f"first_name={_first_name!s}, "
            f"display_name={_display_name!s}, "
            f"home_phone={_home_phone!s}, "
            f"id={_id!s}, "
            f"independent_contractor={_independent_contractor!s}, "
            f"is_male={_is_male!s}, "
            f"last_name={_last_name!s}, "
            f"mobile_phone={_mobile_phone!s}, "
            f"name={_name!s}, "
            f"postal_code={_postal_code!s}, "
            f"class_teacher={_class_teacher!s}, "
            f"sort_order={_sort_order!s}, "
            f"state={_state!s}, "
            f"work_phone={_work_phone!s}, "
            f"image_url={_image_url!s}, "
            f"class_assistant={_class_assistant!s}, "
            f"class_assistant_2={_class_assistant_2!s}, "
            f"employment_start={_employment_start!s}, "
            f"employment_end={_employment_end!s}, "
            f"provider_i_ds={_provider_i_ds!s}, "
            f"rep={_rep!s}, "
            f"rep_2={_rep_2!s}, "
            f"rep_3={_rep_3!s}, "
            f"rep_4={_rep_4!s}, "
            f"rep_5={_rep_5!s}, "
            f"rep_6={_rep_6!s}, "
            f"staff_settings={_staff_settings!s}, "
            f"appointments={_appointments!s}, "
            f"unavailabilities={_unavailabilities!s}, "
            f"availabilities={_availabilities!s}, "
            f"emp_id={_emp_id!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class ClientArrival(object):
    """Implementation of the 'ClientArrival' model.

    Attributes:
        arrival_program_id (int): Arrival program id
        arrival_program_name (str): Arrival program name
        can_access (bool): Property to check client can access arrival service.
        locations_i_ds (List[int]): List of locations where arrival service can
            availed

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "arrival_program_id": "ArrivalProgramID",
        "arrival_program_name": "ArrivalProgramName",
        "can_access": "CanAccess",
        "locations_i_ds": "LocationsIDs",
    }

    _optionals = [
        "arrival_program_id",
        "arrival_program_name",
        "can_access",
        "locations_i_ds",
    ]

    def __init__(
        self,
        arrival_program_id=APIHelper.SKIP,
        arrival_program_name=APIHelper.SKIP,
        can_access=APIHelper.SKIP,
        locations_i_ds=APIHelper.SKIP):
        """Initialize a ClientArrival instance."""
        # Initialize members of the class
        if arrival_program_id is not APIHelper.SKIP:
            self.arrival_program_id = arrival_program_id
        if arrival_program_name is not APIHelper.SKIP:
            self.arrival_program_name = arrival_program_name
        if can_access is not APIHelper.SKIP:
            self.can_access = can_access
        if locations_i_ds is not APIHelper.SKIP:
            self.locations_i_ds = locations_i_ds

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        arrival_program_id =\
            dictionary.get("ArrivalProgramID")\
            if dictionary.get("ArrivalProgramID")\
                else APIHelper.SKIP
        arrival_program_name =\
            dictionary.get("ArrivalProgramName")\
            if dictionary.get("ArrivalProgramName")\
                else APIHelper.SKIP
        can_access =\
            dictionary.get("CanAccess")\
            if "CanAccess" in dictionary.keys()\
                else APIHelper.SKIP
        locations_i_ds =\
            dictionary.get("LocationsIDs")\
            if dictionary.get("LocationsIDs")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(arrival_program_id,
                   arrival_program_name,
                   can_access,
                   locations_i_ds)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _arrival_program_id=(
            self.arrival_program_id
            if hasattr(self, "arrival_program_id")
            else None
        )
        _arrival_program_name=(
            self.arrival_program_name
            if hasattr(self, "arrival_program_name")
            else None
        )
        _can_access=(
            self.can_access
            if hasattr(self, "can_access")
            else None
        )
        _locations_i_ds=(
            self.locations_i_ds
            if hasattr(self, "locations_i_ds")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"arrival_program_id={_arrival_program_id!r}, "
            f"arrival_program_name={_arrival_program_name!r}, "
            f"can_access={_can_access!r}, "
            f"locations_i_ds={_locations_i_ds!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _arrival_program_id=(
            self.arrival_program_id
            if hasattr(self, "arrival_program_id")
            else None
        )
        _arrival_program_name=(
            self.arrival_program_name
            if hasattr(self, "arrival_program_name")
            else None
        )
        _can_access=(
            self.can_access
            if hasattr(self, "can_access")
            else None
        )
        _locations_i_ds=(
            self.locations_i_ds
            if hasattr(self, "locations_i_ds")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"arrival_program_id={_arrival_program_id!s}, "
            f"arrival_program_name={_arrival_program_name!s}, "
            f"can_access={_can_access!s}, "
            f"locations_i_ds={_locations_i_ds!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class AddStaffRequest(object):
    """Implementation of the 'AddStaffRequest' model.

    Attributes:
        first_name (str): The staff member first name. You must specify a first name
            when you add a staff member.
        last_name (str): The staff member last name. You must specify a last name
            when you add a staff member.
        email (str): The staff member’s email address.
        is_male (bool): When `true`, indicates that the staff member is male.  When
            `false`, indicates that the staff member is female.
        home_phone (str): The staff member’s home phone number.
        work_phone (str): The staff member’s work phone number.
        mobile_phone (str): The staff member’s mobile phone number.
        bio (str): The staff member’s biography. This string contains HTML.
        address (str): The first line of the staff member street address.
        address_2 (str): The second line of the staff member street address, if
            needed.
        city (str): The staff member’s city.
        state (str): The staff member’s state.
        country (str): The staff member’s country.
        postal_code (str): The staff member’s postal code.
        class_assistant (bool): Is the staff an assistant
        class_assistant_2 (bool): Is the staff an assistant2
        independent_contractor (bool): When `true`, indicates that the staff member
            is an independent contractor.  When `false`, indicates that the staff
            member is not an independent contractor.
        appointment_instructor (bool): When `true`, indicates that the staff member
            offers appointments.<br />  When `false`, indicates that the staff member
            does not offer appointments.
        always_allow_double_booking (bool): When `true`, indicates that the staff
            member can be scheduled for overlapping services.<br />  When `false`,
            indicates that the staff can only be scheduled for one service at a time
            in any given time-frame.
        class_teacher (bool): When `true`, indicates that the staff member can teach
            classes.  When `false`, indicates that the staff member cannot teach
            classes.
        employment_start (datetime): The start date of employment
        employment_end (datetime): The end date of employment
        sort_order (int): If configured by the business owner, this field determines
            a staff member’s weight when sorting. Use this field to sort staff
            members on your interface.
        provider_i_ds (List[str]): A list of providerIDs for the staff.  In the US it
            is one per staff and is numeric, otherwise it can be a list and is
            alpha-numeric  for more information see <a href="
            https://support.mindbodyonline.com/s/article/204075743-Provider-IDs?langua
            ge=en_US" target="blank">Provider IDs</a>
        notes (str): The staff member private notes.
        emp_id (str): The custom staff ID assigned to the staff member.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "first_name": "FirstName",
        "last_name": "LastName",
        "email": "Email",
        "is_male": "IsMale",
        "home_phone": "HomePhone",
        "work_phone": "WorkPhone",
        "mobile_phone": "MobilePhone",
        "bio": "Bio",
        "address": "Address",
        "address_2": "Address2",
        "city": "City",
        "state": "State",
        "country": "Country",
        "postal_code": "PostalCode",
        "class_assistant": "ClassAssistant",
        "class_assistant_2": "ClassAssistant2",
        "independent_contractor": "IndependentContractor",
        "appointment_instructor": "AppointmentInstructor",
        "always_allow_double_booking": "AlwaysAllowDoubleBooking",
        "class_teacher": "ClassTeacher",
        "employment_start": "EmploymentStart",
        "employment_end": "EmploymentEnd",
        "sort_order": "SortOrder",
        "provider_i_ds": "ProviderIDs",
        "notes": "Notes",
        "emp_id": "EmpID",
    }

    _optionals = [
        "email",
        "is_male",
        "home_phone",
        "work_phone",
        "mobile_phone",
        "bio",
        "address",
        "address_2",
        "city",
        "state",
        "country",
        "postal_code",
        "class_assistant",
        "class_assistant_2",
        "independent_contractor",
        "appointment_instructor",
        "always_allow_double_booking",
        "class_teacher",
        "employment_start",
        "employment_end",
        "sort_order",
        "provider_i_ds",
        "notes",
        "emp_id",
    ]

    def __init__(
        self,
        first_name=None,
        last_name=None,
        email=APIHelper.SKIP,
        is_male=APIHelper.SKIP,
        home_phone=APIHelper.SKIP,
        work_phone=APIHelper.SKIP,
        mobile_phone=APIHelper.SKIP,
        bio=APIHelper.SKIP,
        address=APIHelper.SKIP,
        address_2=APIHelper.SKIP,
        city=APIHelper.SKIP,
        state=APIHelper.SKIP,
        country=APIHelper.SKIP,
        postal_code=APIHelper.SKIP,
        class_assistant=APIHelper.SKIP,
        class_assistant_2=APIHelper.SKIP,
        independent_contractor=APIHelper.SKIP,
        appointment_instructor=APIHelper.SKIP,
        always_allow_double_booking=APIHelper.SKIP,
        class_teacher=APIHelper.SKIP,
        employment_start=APIHelper.SKIP,
        employment_end=APIHelper.SKIP,
        sort_order=APIHelper.SKIP,
        provider_i_ds=APIHelper.SKIP,
        notes=APIHelper.SKIP,
        emp_id=APIHelper.SKIP):
        """Initialize a AddStaffRequest instance."""
        # Initialize members of the class
        self.first_name = first_name
        self.last_name = last_name
        if email is not APIHelper.SKIP:
            self.email = email
        if is_male is not APIHelper.SKIP:
            self.is_male = is_male
        if home_phone is not APIHelper.SKIP:
            self.home_phone = home_phone
        if work_phone is not APIHelper.SKIP:
            self.work_phone = work_phone
        if mobile_phone is not APIHelper.SKIP:
            self.mobile_phone = mobile_phone
        if bio is not APIHelper.SKIP:
            self.bio = bio
        if address is not APIHelper.SKIP:
            self.address = address
        if address_2 is not APIHelper.SKIP:
            self.address_2 = address_2
        if city is not APIHelper.SKIP:
            self.city = city
        if state is not APIHelper.SKIP:
            self.state = state
        if country is not APIHelper.SKIP:
            self.country = country
        if postal_code is not APIHelper.SKIP:
            self.postal_code = postal_code
        if class_assistant is not APIHelper.SKIP:
            self.class_assistant = class_assistant
        if class_assistant_2 is not APIHelper.SKIP:
            self.class_assistant_2 = class_assistant_2
        if independent_contractor is not APIHelper.SKIP:
            self.independent_contractor = independent_contractor
        if appointment_instructor is not APIHelper.SKIP:
            self.appointment_instructor = appointment_instructor
        if always_allow_double_booking is not APIHelper.SKIP:
            self.always_allow_double_booking = always_allow_double_booking
        if class_teacher is not APIHelper.SKIP:
            self.class_teacher = class_teacher
        if employment_start is not APIHelper.SKIP:
            self.employment_start =\
                 APIHelper.apply_datetime_converter(
                employment_start, APIHelper.RFC3339DateTime)\
                 if employment_start else None
        if employment_end is not APIHelper.SKIP:
            self.employment_end =\
                 APIHelper.apply_datetime_converter(
                employment_end, APIHelper.RFC3339DateTime)\
                 if employment_end else None
        if sort_order is not APIHelper.SKIP:
            self.sort_order = sort_order
        if provider_i_ds is not APIHelper.SKIP:
            self.provider_i_ds = provider_i_ds
        if notes is not APIHelper.SKIP:
            self.notes = notes
        if emp_id is not APIHelper.SKIP:
            self.emp_id = emp_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        first_name =\
            dictionary.get("FirstName")\
            if dictionary.get("FirstName")\
                else None
        last_name =\
            dictionary.get("LastName")\
            if dictionary.get("LastName")\
                else None
        email =\
            dictionary.get("Email")\
            if dictionary.get("Email")\
                else APIHelper.SKIP
        is_male =\
            dictionary.get("IsMale")\
            if "IsMale" in dictionary.keys()\
                else APIHelper.SKIP
        home_phone =\
            dictionary.get("HomePhone")\
            if dictionary.get("HomePhone")\
                else APIHelper.SKIP
        work_phone =\
            dictionary.get("WorkPhone")\
            if dictionary.get("WorkPhone")\
                else APIHelper.SKIP
        mobile_phone =\
            dictionary.get("MobilePhone")\
            if dictionary.get("MobilePhone")\
                else APIHelper.SKIP
        bio =\
            dictionary.get("Bio")\
            if dictionary.get("Bio")\
                else APIHelper.SKIP
        address =\
            dictionary.get("Address")\
            if dictionary.get("Address")\
                else APIHelper.SKIP
        address_2 =\
            dictionary.get("Address2")\
            if dictionary.get("Address2")\
                else APIHelper.SKIP
        city =\
            dictionary.get("City")\
            if dictionary.get("City")\
                else APIHelper.SKIP
        state =\
            dictionary.get("State")\
            if dictionary.get("State")\
                else APIHelper.SKIP
        country =\
            dictionary.get("Country")\
            if dictionary.get("Country")\
                else APIHelper.SKIP
        postal_code =\
            dictionary.get("PostalCode")\
            if dictionary.get("PostalCode")\
                else APIHelper.SKIP
        class_assistant =\
            dictionary.get("ClassAssistant")\
            if "ClassAssistant" in dictionary.keys()\
                else APIHelper.SKIP
        class_assistant_2 =\
            dictionary.get("ClassAssistant2")\
            if "ClassAssistant2" in dictionary.keys()\
                else APIHelper.SKIP
        independent_contractor =\
            dictionary.get("IndependentContractor")\
            if "IndependentContractor" in dictionary.keys()\
                else APIHelper.SKIP
        appointment_instructor =\
            dictionary.get("AppointmentInstructor")\
            if "AppointmentInstructor" in dictionary.keys()\
                else APIHelper.SKIP
        always_allow_double_booking =\
            dictionary.get("AlwaysAllowDoubleBooking")\
            if "AlwaysAllowDoubleBooking" in dictionary.keys()\
                else APIHelper.SKIP
        class_teacher =\
            dictionary.get("ClassTeacher")\
            if "ClassTeacher" in dictionary.keys()\
                else APIHelper.SKIP
        employment_start = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EmploymentStart")).datetime\
            if dictionary.get("EmploymentStart") else APIHelper.SKIP
        employment_end = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EmploymentEnd")).datetime\
            if dictionary.get("EmploymentEnd") else APIHelper.SKIP
        sort_order =\
            dictionary.get("SortOrder")\
            if dictionary.get("SortOrder")\
                else APIHelper.SKIP
        provider_i_ds =\
            dictionary.get("ProviderIDs")\
            if dictionary.get("ProviderIDs")\
                else APIHelper.SKIP
        notes =\
            dictionary.get("Notes")\
            if dictionary.get("Notes")\
                else APIHelper.SKIP
        emp_id =\
            dictionary.get("EmpID")\
            if dictionary.get("EmpID")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(first_name,
                   last_name,
                   email,
                   is_male,
                   home_phone,
                   work_phone,
                   mobile_phone,
                   bio,
                   address,
                   address_2,
                   city,
                   state,
                   country,
                   postal_code,
                   class_assistant,
                   class_assistant_2,
                   independent_contractor,
                   appointment_instructor,
                   always_allow_double_booking,
                   class_teacher,
                   employment_start,
                   employment_end,
                   sort_order,
                   provider_i_ds,
                   notes,
                   emp_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _first_name=self.first_name
        _last_name=self.last_name
        _email=(
            self.email
            if hasattr(self, "email")
            else None
        )
        _is_male=(
            self.is_male
            if hasattr(self, "is_male")
            else None
        )
        _home_phone=(
            self.home_phone
            if hasattr(self, "home_phone")
            else None
        )
        _work_phone=(
            self.work_phone
            if hasattr(self, "work_phone")
            else None
        )
        _mobile_phone=(
            self.mobile_phone
            if hasattr(self, "mobile_phone")
            else None
        )
        _bio=(
            self.bio
            if hasattr(self, "bio")
            else None
        )
        _address=(
            self.address
            if hasattr(self, "address")
            else None
        )
        _address_2=(
            self.address_2
            if hasattr(self, "address_2")
            else None
        )
        _city=(
            self.city
            if hasattr(self, "city")
            else None
        )
        _state=(
            self.state
            if hasattr(self, "state")
            else None
        )
        _country=(
            self.country
            if hasattr(self, "country")
            else None
        )
        _postal_code=(
            self.postal_code
            if hasattr(self, "postal_code")
            else None
        )
        _class_assistant=(
            self.class_assistant
            if hasattr(self, "class_assistant")
            else None
        )
        _class_assistant_2=(
            self.class_assistant_2
            if hasattr(self, "class_assistant_2")
            else None
        )
        _independent_contractor=(
            self.independent_contractor
            if hasattr(self, "independent_contractor")
            else None
        )
        _appointment_instructor=(
            self.appointment_instructor
            if hasattr(self, "appointment_instructor")
            else None
        )
        _always_allow_double_booking=(
            self.always_allow_double_booking
            if hasattr(self, "always_allow_double_booking")
            else None
        )
        _class_teacher=(
            self.class_teacher
            if hasattr(self, "class_teacher")
            else None
        )
        _employment_start=(
            self.employment_start
            if hasattr(self, "employment_start")
            else None
        )
        _employment_end=(
            self.employment_end
            if hasattr(self, "employment_end")
            else None
        )
        _sort_order=(
            self.sort_order
            if hasattr(self, "sort_order")
            else None
        )
        _provider_i_ds=(
            self.provider_i_ds
            if hasattr(self, "provider_i_ds")
            else None
        )
        _notes=(
            self.notes
            if hasattr(self, "notes")
            else None
        )
        _emp_id=(
            self.emp_id
            if hasattr(self, "emp_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"first_name={_first_name!r}, "
            f"last_name={_last_name!r}, "
            f"email={_email!r}, "
            f"is_male={_is_male!r}, "
            f"home_phone={_home_phone!r}, "
            f"work_phone={_work_phone!r}, "
            f"mobile_phone={_mobile_phone!r}, "
            f"bio={_bio!r}, "
            f"address={_address!r}, "
            f"address_2={_address_2!r}, "
            f"city={_city!r}, "
            f"state={_state!r}, "
            f"country={_country!r}, "
            f"postal_code={_postal_code!r}, "
            f"class_assistant={_class_assistant!r}, "
            f"class_assistant_2={_class_assistant_2!r}, "
            f"independent_contractor={_independent_contractor!r}, "
            f"appointment_instructor={_appointment_instructor!r}, "
            f"always_allow_double_booking={_always_allow_double_booking!r}, "
            f"class_teacher={_class_teacher!r}, "
            f"employment_start={_employment_start!r}, "
            f"employment_end={_employment_end!r}, "
            f"sort_order={_sort_order!r}, "
            f"provider_i_ds={_provider_i_ds!r}, "
            f"notes={_notes!r}, "
            f"emp_id={_emp_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _first_name=self.first_name
        _last_name=self.last_name
        _email=(
            self.email
            if hasattr(self, "email")
            else None
        )
        _is_male=(
            self.is_male
            if hasattr(self, "is_male")
            else None
        )
        _home_phone=(
            self.home_phone
            if hasattr(self, "home_phone")
            else None
        )
        _work_phone=(
            self.work_phone
            if hasattr(self, "work_phone")
            else None
        )
        _mobile_phone=(
            self.mobile_phone
            if hasattr(self, "mobile_phone")
            else None
        )
        _bio=(
            self.bio
            if hasattr(self, "bio")
            else None
        )
        _address=(
            self.address
            if hasattr(self, "address")
            else None
        )
        _address_2=(
            self.address_2
            if hasattr(self, "address_2")
            else None
        )
        _city=(
            self.city
            if hasattr(self, "city")
            else None
        )
        _state=(
            self.state
            if hasattr(self, "state")
            else None
        )
        _country=(
            self.country
            if hasattr(self, "country")
            else None
        )
        _postal_code=(
            self.postal_code
            if hasattr(self, "postal_code")
            else None
        )
        _class_assistant=(
            self.class_assistant
            if hasattr(self, "class_assistant")
            else None
        )
        _class_assistant_2=(
            self.class_assistant_2
            if hasattr(self, "class_assistant_2")
            else None
        )
        _independent_contractor=(
            self.independent_contractor
            if hasattr(self, "independent_contractor")
            else None
        )
        _appointment_instructor=(
            self.appointment_instructor
            if hasattr(self, "appointment_instructor")
            else None
        )
        _always_allow_double_booking=(
            self.always_allow_double_booking
            if hasattr(self, "always_allow_double_booking")
            else None
        )
        _class_teacher=(
            self.class_teacher
            if hasattr(self, "class_teacher")
            else None
        )
        _employment_start=(
            self.employment_start
            if hasattr(self, "employment_start")
            else None
        )
        _employment_end=(
            self.employment_end
            if hasattr(self, "employment_end")
            else None
        )
        _sort_order=(
            self.sort_order
            if hasattr(self, "sort_order")
            else None
        )
        _provider_i_ds=(
            self.provider_i_ds
            if hasattr(self, "provider_i_ds")
            else None
        )
        _notes=(
            self.notes
            if hasattr(self, "notes")
            else None
        )
        _emp_id=(
            self.emp_id
            if hasattr(self, "emp_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"first_name={_first_name!s}, "
            f"last_name={_last_name!s}, "
            f"email={_email!s}, "
            f"is_male={_is_male!s}, "
            f"home_phone={_home_phone!s}, "
            f"work_phone={_work_phone!s}, "
            f"mobile_phone={_mobile_phone!s}, "
            f"bio={_bio!s}, "
            f"address={_address!s}, "
            f"address_2={_address_2!s}, "
            f"city={_city!s}, "
            f"state={_state!s}, "
            f"country={_country!s}, "
            f"postal_code={_postal_code!s}, "
            f"class_assistant={_class_assistant!s}, "
            f"class_assistant_2={_class_assistant_2!s}, "
            f"independent_contractor={_independent_contractor!s}, "
            f"appointment_instructor={_appointment_instructor!s}, "
            f"always_allow_double_booking={_always_allow_double_booking!s}, "
            f"class_teacher={_class_teacher!s}, "
            f"employment_start={_employment_start!s}, "
            f"employment_end={_employment_end!s}, "
            f"sort_order={_sort_order!s}, "
            f"provider_i_ds={_provider_i_ds!s}, "
            f"notes={_notes!s}, "
            f"emp_id={_emp_id!s}, "
            f")"
        )




"""
mindbodypublicapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from apimatic_core.http.request.http_request import HttpRequest as CoreHttpRequest


class HttpRequest(CoreHttpRequest):
    """
    Represent an HTTP request to be sent to the server.

    Encapsulates request details such as the HTTP method, target URL, headers,
     query parameters, body parameters, and any files included with the request.

    Attributes:
        http_method: The HTTP method to use for the request.
        query_url (str): The URL to which the request will be sent.
        headers (dict[str, str] | None): Headers to include with the request.
        query_parameters (dict[str, str] | None): Query parameters appended
            to the request URL.
        parameters (dict[str, str] | None): Form or body parameters sent
            with the request.
        files (dict | None): Files to be sent with the request.

    """

    def __init__(self,
                 http_method,
                 query_url,
                 headers=None,
                 query_parameters=None,
                 parameters=None,
                 files=None):
        """
        Initialize an HttpRequest instance.

        Args:
            http_method: The HTTP method to use for the request.
            query_url: The URL to which the request will be sent.
            headers: Headers to include with the request.
            query_parameters: Query parameters appended to the request URL.
            parameters: Form or body parameters sent with the request.
            files: Files to be sent with the request.

        """
        super().__init__(http_method,
                         query_url,
                         headers,
                         query_parameters,
                         parameters,
                         files)



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.relationship import (
    Relationship,
)


class ClientRelationship(object):
    """Implementation of the 'ClientRelationship' model.

    A relation between two clients.

    Attributes:
        related_client_id (str): The RSSID of the related client.
        related_unique_id (int): The UniqueId of the related client.
        relationship (Relationship): Jim is a RelationshipName1 of John. John is a
            RelationshipName2 of Jim.
        relationship_name (str): The name of the relationship of the related client.
        delete (bool): When true, the associated relationship is removed from the
            client’s list of relationships.  This property is ignored in all other
            use cases.  Default: *false*

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "related_client_id": "RelatedClientId",
        "related_unique_id": "RelatedUniqueId",
        "relationship": "Relationship",
        "relationship_name": "RelationshipName",
        "delete": "Delete",
    }

    _optionals = [
        "related_client_id",
        "related_unique_id",
        "relationship",
        "relationship_name",
        "delete",
    ]

    def __init__(
        self,
        related_client_id=APIHelper.SKIP,
        related_unique_id=APIHelper.SKIP,
        relationship=APIHelper.SKIP,
        relationship_name=APIHelper.SKIP,
        delete=APIHelper.SKIP):
        """Initialize a ClientRelationship instance."""
        # Initialize members of the class
        if related_client_id is not APIHelper.SKIP:
            self.related_client_id = related_client_id
        if related_unique_id is not APIHelper.SKIP:
            self.related_unique_id = related_unique_id
        if relationship is not APIHelper.SKIP:
            self.relationship = relationship
        if relationship_name is not APIHelper.SKIP:
            self.relationship_name = relationship_name
        if delete is not APIHelper.SKIP:
            self.delete = delete

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        related_client_id =\
            dictionary.get("RelatedClientId")\
            if dictionary.get("RelatedClientId")\
                else APIHelper.SKIP
        related_unique_id =\
            dictionary.get("RelatedUniqueId")\
            if dictionary.get("RelatedUniqueId")\
                else APIHelper.SKIP
        relationship =\
            Relationship.from_dictionary(
                dictionary.get("Relationship"))\
                if "Relationship" in dictionary.keys()\
                else APIHelper.SKIP
        relationship_name =\
            dictionary.get("RelationshipName")\
            if dictionary.get("RelationshipName")\
                else APIHelper.SKIP
        delete =\
            dictionary.get("Delete")\
            if "Delete" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(related_client_id,
                   related_unique_id,
                   relationship,
                   relationship_name,
                   delete)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _related_client_id=(
            self.related_client_id
            if hasattr(self, "related_client_id")
            else None
        )
        _related_unique_id=(
            self.related_unique_id
            if hasattr(self, "related_unique_id")
            else None
        )
        _relationship=(
            self.relationship
            if hasattr(self, "relationship")
            else None
        )
        _relationship_name=(
            self.relationship_name
            if hasattr(self, "relationship_name")
            else None
        )
        _delete=(
            self.delete
            if hasattr(self, "delete")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"related_client_id={_related_client_id!r}, "
            f"related_unique_id={_related_unique_id!r}, "
            f"relationship={_relationship!r}, "
            f"relationship_name={_relationship_name!r}, "
            f"delete={_delete!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _related_client_id=(
            self.related_client_id
            if hasattr(self, "related_client_id")
            else None
        )
        _related_unique_id=(
            self.related_unique_id
            if hasattr(self, "related_unique_id")
            else None
        )
        _relationship=(
            self.relationship
            if hasattr(self, "relationship")
            else None
        )
        _relationship_name=(
            self.relationship_name
            if hasattr(self, "relationship_name")
            else None
        )
        _delete=(
            self.delete
            if hasattr(self, "delete")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"related_client_id={_related_client_id!s}, "
            f"related_unique_id={_related_unique_id!s}, "
            f"relationship={_relationship!s}, "
            f"relationship_name={_relationship_name!s}, "
            f"delete={_delete!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.appointment_1 import (
    Appointment1,
)
from mindbodypublicapi.models.availability_1 import (
    Availability1,
)
from mindbodypublicapi.models.location_1 import (
    Location1,
)
from mindbodypublicapi.models.staff_setting import (
    StaffSetting,
)
from mindbodypublicapi.models.unavailability_1 import (
    Unavailability1,
)


class Staff1(object):
    """Implementation of the 'Staff1' model.

    Attributes:
        id (int): The ID assigned to the staff member.
        first_name (str): The staff member’s first name.
        last_name (str): The staff member’s last name.
        display_name (str): The display name of the staff member.
        email (str): The staff member’s email address.
        bio (str): The staff member’s biography. This string contains HTML.
        address (str): The address of the staff member who is teaching the class.
        address_2 (str): The address2 of the staff member who is teaching the class.
        city (str): The staff member’s city.
        state (str): The staff member’s state.
        postal_code (str): The staff member’s postal code.
        foreign_zip (str): The staff member’s Foreign Zip code.
        country (str): The staff member’s country.
        work_phone (str): The staff member’s work phone number.
        home_phone (str): The staff member’s home phone number.
        cell_phone (str): The staff member’s mobile phone number.
        active (bool): When `true`, indicates that the staff member is Active.  When
            `false`, indicates that the staff member is not Active.
        is_system (bool): When `true`, indicates that the staff member is a system .
            When `false`, indicates that the staff member is not system.
        smode_id (int): The Staff's Smode Id
        appointment_trn (bool): When `true`, indicates that the staff member offers
            appointments.  When `false`, indicates that the staff member does not
            offer appointments.
        always_allow_double_booking (bool): When `true`, indicates that the staff
            member can be scheduled for overlapping services.  When `false`,
            indicates that the staff can only be scheduled for one service at a time
            in any given time-frame.
        independent_contractor (bool): When `true`, indicates that the staff member
            is an independent contractor.  When `false`, indicates that the staff
            member is not an independent contractor.
        image_url (str): The URL of the staff member’s image, if one has been
            uploaded.
        is_male (bool): When `true`, indicates that the staff member is male.  When
            `false`, indicates that the staff member is female.
        reservation_trn (bool): When `true`, indicates that the staff member offers
            Reservation.  When `false`, indicates that the staff member does not
            offer Reservation.
        sort_order (int): If configured by the business owner, this field determines
            a staff member’s weight when sorting. Use this field to sort staff
            members on your interface.
        multi_location_permission (bool): When `true`, indicates that the staff
            member has Multi Location Permission.  When `false`, indicates that the
            staff member does not has Multi Location Permission.
        name (str): The staff member’s name.
        provider_i_ds (List[str]): A list of ProviderIds for the staff.
        staff_settings (StaffSetting): contains the information about the staff
            settings.
        rep (bool): When `true`, indicates that the staff is sales Rep 1 else `false`.
        rep_2 (bool): When `true`, indicates that the staff is sales Rep 2 else
            `false`.
        rep_3 (bool): When `true`, indicates that the staff is sales Rep 3 else
            `false`.
        rep_4 (bool): When `true`, indicates that the staff is sales Rep 4 else
            `false`.
        rep_5 (bool): When `true`, indicates that the staff is sales Rep 5 else
            `false`.
        rep_6 (bool): When `true`, indicates that the staff is sales Rep 6 else
            `false`.
        assistant (bool): When `true`, indicates that the staff is assistant.  When
            `false`, indicates that the staff is not assistant.
        assistant_2 (bool): When `true`, indicates that the staff is assistant2.
            When `false`, indicates that the staff is not assistant2.
        employment_start (datetime): The start date of employment.
        employment_end (datetime): The end date of employment.
        emp_id (str): The custom staff ID assigned to the staff member.
        appointments (List[Appointment1]): A list of appointments for the staff.
        unavailabilities (List[Unavailability1]): A list of unavailabilities for the
            staff.
        availabilities (List[Availability1]): A list of availabilities for the staff.
        login_locations (List[Location1]): A list of LoginLocations for the staff

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "first_name": "FirstName",
        "last_name": "LastName",
        "display_name": "DisplayName",
        "email": "Email",
        "bio": "Bio",
        "address": "Address",
        "address_2": "Address2",
        "city": "City",
        "state": "State",
        "postal_code": "PostalCode",
        "foreign_zip": "ForeignZip",
        "country": "Country",
        "work_phone": "WorkPhone",
        "home_phone": "HomePhone",
        "cell_phone": "CellPhone",
        "active": "Active",
        "is_system": "IsSystem",
        "smode_id": "SmodeId",
        "appointment_trn": "AppointmentTrn",
        "always_allow_double_booking": "AlwaysAllowDoubleBooking",
        "independent_contractor": "IndependentContractor",
        "image_url": "ImageUrl",
        "is_male": "IsMale",
        "reservation_trn": "ReservationTrn",
        "sort_order": "SortOrder",
        "multi_location_permission": "MultiLocationPermission",
        "name": "Name",
        "provider_i_ds": "ProviderIDs",
        "staff_settings": "StaffSettings",
        "rep": "Rep",
        "rep_2": "Rep2",
        "rep_3": "Rep3",
        "rep_4": "Rep4",
        "rep_5": "Rep5",
        "rep_6": "Rep6",
        "assistant": "Assistant",
        "assistant_2": "Assistant2",
        "employment_start": "EmploymentStart",
        "employment_end": "EmploymentEnd",
        "emp_id": "EmpID",
        "appointments": "Appointments",
        "unavailabilities": "Unavailabilities",
        "availabilities": "Availabilities",
        "login_locations": "LoginLocations",
    }

    _optionals = [
        "id",
        "first_name",
        "last_name",
        "display_name",
        "email",
        "bio",
        "address",
        "address_2",
        "city",
        "state",
        "postal_code",
        "foreign_zip",
        "country",
        "work_phone",
        "home_phone",
        "cell_phone",
        "active",
        "is_system",
        "smode_id",
        "appointment_trn",
        "always_allow_double_booking",
        "independent_contractor",
        "image_url",
        "is_male",
        "reservation_trn",
        "sort_order",
        "multi_location_permission",
        "name",
        "provider_i_ds",
        "staff_settings",
        "rep",
        "rep_2",
        "rep_3",
        "rep_4",
        "rep_5",
        "rep_6",
        "assistant",
        "assistant_2",
        "employment_start",
        "employment_end",
        "emp_id",
        "appointments",
        "unavailabilities",
        "availabilities",
        "login_locations",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        first_name=APIHelper.SKIP,
        last_name=APIHelper.SKIP,
        display_name=APIHelper.SKIP,
        email=APIHelper.SKIP,
        bio=APIHelper.SKIP,
        address=APIHelper.SKIP,
        address_2=APIHelper.SKIP,
        city=APIHelper.SKIP,
        state=APIHelper.SKIP,
        postal_code=APIHelper.SKIP,
        foreign_zip=APIHelper.SKIP,
        country=APIHelper.SKIP,
        work_phone=APIHelper.SKIP,
        home_phone=APIHelper.SKIP,
        cell_phone=APIHelper.SKIP,
        active=APIHelper.SKIP,
        is_system=APIHelper.SKIP,
        smode_id=APIHelper.SKIP,
        appointment_trn=APIHelper.SKIP,
        always_allow_double_booking=APIHelper.SKIP,
        independent_contractor=APIHelper.SKIP,
        image_url=APIHelper.SKIP,
        is_male=APIHelper.SKIP,
        reservation_trn=APIHelper.SKIP,
        sort_order=APIHelper.SKIP,
        multi_location_permission=APIHelper.SKIP,
        name=APIHelper.SKIP,
        provider_i_ds=APIHelper.SKIP,
        staff_settings=APIHelper.SKIP,
        rep=APIHelper.SKIP,
        rep_2=APIHelper.SKIP,
        rep_3=APIHelper.SKIP,
        rep_4=APIHelper.SKIP,
        rep_5=APIHelper.SKIP,
        rep_6=APIHelper.SKIP,
        assistant=APIHelper.SKIP,
        assistant_2=APIHelper.SKIP,
        employment_start=APIHelper.SKIP,
        employment_end=APIHelper.SKIP,
        emp_id=APIHelper.SKIP,
        appointments=APIHelper.SKIP,
        unavailabilities=APIHelper.SKIP,
        availabilities=APIHelper.SKIP,
        login_locations=APIHelper.SKIP):
        """Initialize a Staff1 instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if first_name is not APIHelper.SKIP:
            self.first_name = first_name
        if last_name is not APIHelper.SKIP:
            self.last_name = last_name
        if display_name is not APIHelper.SKIP:
            self.display_name = display_name
        if email is not APIHelper.SKIP:
            self.email = email
        if bio is not APIHelper.SKIP:
            self.bio = bio
        if address is not APIHelper.SKIP:
            self.address = address
        if address_2 is not APIHelper.SKIP:
            self.address_2 = address_2
        if city is not APIHelper.SKIP:
            self.city = city
        if state is not APIHelper.SKIP:
            self.state = state
        if postal_code is not APIHelper.SKIP:
            self.postal_code = postal_code
        if foreign_zip is not APIHelper.SKIP:
            self.foreign_zip = foreign_zip
        if country is not APIHelper.SKIP:
            self.country = country
        if work_phone is not APIHelper.SKIP:
            self.work_phone = work_phone
        if home_phone is not APIHelper.SKIP:
            self.home_phone = home_phone
        if cell_phone is not APIHelper.SKIP:
            self.cell_phone = cell_phone
        if active is not APIHelper.SKIP:
            self.active = active
        if is_system is not APIHelper.SKIP:
            self.is_system = is_system
        if smode_id is not APIHelper.SKIP:
            self.smode_id = smode_id
        if appointment_trn is not APIHelper.SKIP:
            self.appointment_trn = appointment_trn
        if always_allow_double_booking is not APIHelper.SKIP:
            self.always_allow_double_booking = always_allow_double_booking
        if independent_contractor is not APIHelper.SKIP:
            self.independent_contractor = independent_contractor
        if image_url is not APIHelper.SKIP:
            self.image_url = image_url
        if is_male is not APIHelper.SKIP:
            self.is_male = is_male
        if reservation_trn is not APIHelper.SKIP:
            self.reservation_trn = reservation_trn
        if sort_order is not APIHelper.SKIP:
            self.sort_order = sort_order
        if multi_location_permission is not APIHelper.SKIP:
            self.multi_location_permission = multi_location_permission
        if name is not APIHelper.SKIP:
            self.name = name
        if provider_i_ds is not APIHelper.SKIP:
            self.provider_i_ds = provider_i_ds
        if staff_settings is not APIHelper.SKIP:
            self.staff_settings = staff_settings
        if rep is not APIHelper.SKIP:
            self.rep = rep
        if rep_2 is not APIHelper.SKIP:
            self.rep_2 = rep_2
        if rep_3 is not APIHelper.SKIP:
            self.rep_3 = rep_3
        if rep_4 is not APIHelper.SKIP:
            self.rep_4 = rep_4
        if rep_5 is not APIHelper.SKIP:
            self.rep_5 = rep_5
        if rep_6 is not APIHelper.SKIP:
            self.rep_6 = rep_6
        if assistant is not APIHelper.SKIP:
            self.assistant = assistant
        if assistant_2 is not APIHelper.SKIP:
            self.assistant_2 = assistant_2
        if employment_start is not APIHelper.SKIP:
            self.employment_start =\
                 APIHelper.apply_datetime_converter(
                employment_start, APIHelper.RFC3339DateTime)\
                 if employment_start else None
        if employment_end is not APIHelper.SKIP:
            self.employment_end =\
                 APIHelper.apply_datetime_converter(
                employment_end, APIHelper.RFC3339DateTime)\
                 if employment_end else None
        if emp_id is not APIHelper.SKIP:
            self.emp_id = emp_id
        if appointments is not APIHelper.SKIP:
            self.appointments = appointments
        if unavailabilities is not APIHelper.SKIP:
            self.unavailabilities = unavailabilities
        if availabilities is not APIHelper.SKIP:
            self.availabilities = availabilities
        if login_locations is not APIHelper.SKIP:
            self.login_locations = login_locations

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        first_name =\
            dictionary.get("FirstName")\
            if dictionary.get("FirstName")\
                else APIHelper.SKIP
        last_name =\
            dictionary.get("LastName")\
            if dictionary.get("LastName")\
                else APIHelper.SKIP
        display_name =\
            dictionary.get("DisplayName")\
            if dictionary.get("DisplayName")\
                else APIHelper.SKIP
        email =\
            dictionary.get("Email")\
            if dictionary.get("Email")\
                else APIHelper.SKIP
        bio =\
            dictionary.get("Bio")\
            if dictionary.get("Bio")\
                else APIHelper.SKIP
        address =\
            dictionary.get("Address")\
            if dictionary.get("Address")\
                else APIHelper.SKIP
        address_2 =\
            dictionary.get("Address2")\
            if dictionary.get("Address2")\
                else APIHelper.SKIP
        city =\
            dictionary.get("City")\
            if dictionary.get("City")\
                else APIHelper.SKIP
        state =\
            dictionary.get("State")\
            if dictionary.get("State")\
                else APIHelper.SKIP
        postal_code =\
            dictionary.get("PostalCode")\
            if dictionary.get("PostalCode")\
                else APIHelper.SKIP
        foreign_zip =\
            dictionary.get("ForeignZip")\
            if dictionary.get("ForeignZip")\
                else APIHelper.SKIP
        country =\
            dictionary.get("Country")\
            if dictionary.get("Country")\
                else APIHelper.SKIP
        work_phone =\
            dictionary.get("WorkPhone")\
            if dictionary.get("WorkPhone")\
                else APIHelper.SKIP
        home_phone =\
            dictionary.get("HomePhone")\
            if dictionary.get("HomePhone")\
                else APIHelper.SKIP
        cell_phone =\
            dictionary.get("CellPhone")\
            if dictionary.get("CellPhone")\
                else APIHelper.SKIP
        active =\
            dictionary.get("Active")\
            if "Active" in dictionary.keys()\
                else APIHelper.SKIP
        is_system =\
            dictionary.get("IsSystem")\
            if "IsSystem" in dictionary.keys()\
                else APIHelper.SKIP
        smode_id =\
            dictionary.get("SmodeId")\
            if dictionary.get("SmodeId")\
                else APIHelper.SKIP
        appointment_trn =\
            dictionary.get("AppointmentTrn")\
            if "AppointmentTrn" in dictionary.keys()\
                else APIHelper.SKIP
        always_allow_double_booking =\
            dictionary.get("AlwaysAllowDoubleBooking")\
            if "AlwaysAllowDoubleBooking" in dictionary.keys()\
                else APIHelper.SKIP
        independent_contractor =\
            dictionary.get("IndependentContractor")\
            if "IndependentContractor" in dictionary.keys()\
                else APIHelper.SKIP
        image_url =\
            dictionary.get("ImageUrl")\
            if dictionary.get("ImageUrl")\
                else APIHelper.SKIP
        is_male =\
            dictionary.get("IsMale")\
            if "IsMale" in dictionary.keys()\
                else APIHelper.SKIP
        reservation_trn =\
            dictionary.get("ReservationTrn")\
            if "ReservationTrn" in dictionary.keys()\
                else APIHelper.SKIP
        sort_order =\
            dictionary.get("SortOrder")\
            if dictionary.get("SortOrder")\
                else APIHelper.SKIP
        multi_location_permission =\
            dictionary.get("MultiLocationPermission")\
            if "MultiLocationPermission" in dictionary.keys()\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        provider_i_ds =\
            dictionary.get("ProviderIDs")\
            if dictionary.get("ProviderIDs")\
                else APIHelper.SKIP
        staff_settings =\
            StaffSetting.from_dictionary(
                dictionary.get("StaffSettings"))\
                if "StaffSettings" in dictionary.keys()\
                else APIHelper.SKIP
        rep =\
            dictionary.get("Rep")\
            if "Rep" in dictionary.keys()\
                else APIHelper.SKIP
        rep_2 =\
            dictionary.get("Rep2")\
            if "Rep2" in dictionary.keys()\
                else APIHelper.SKIP
        rep_3 =\
            dictionary.get("Rep3")\
            if "Rep3" in dictionary.keys()\
                else APIHelper.SKIP
        rep_4 =\
            dictionary.get("Rep4")\
            if "Rep4" in dictionary.keys()\
                else APIHelper.SKIP
        rep_5 =\
            dictionary.get("Rep5")\
            if "Rep5" in dictionary.keys()\
                else APIHelper.SKIP
        rep_6 =\
            dictionary.get("Rep6")\
            if "Rep6" in dictionary.keys()\
                else APIHelper.SKIP
        assistant =\
            dictionary.get("Assistant")\
            if "Assistant" in dictionary.keys()\
                else APIHelper.SKIP
        assistant_2 =\
            dictionary.get("Assistant2")\
            if "Assistant2" in dictionary.keys()\
                else APIHelper.SKIP
        employment_start = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EmploymentStart")).datetime\
            if dictionary.get("EmploymentStart") else APIHelper.SKIP
        employment_end = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EmploymentEnd")).datetime\
            if dictionary.get("EmploymentEnd") else APIHelper.SKIP
        emp_id =\
            dictionary.get("EmpID")\
            if dictionary.get("EmpID")\
                else APIHelper.SKIP
        appointments = None
        if dictionary.get("Appointments") is not None:
            appointments = [
                Appointment1.from_dictionary(x)
                    for x in dictionary.get("Appointments")
            ]
        else:
            appointments = APIHelper.SKIP
        unavailabilities = None
        if dictionary.get("Unavailabilities") is not None:
            unavailabilities = [
                Unavailability1.from_dictionary(x)
                    for x in dictionary.get("Unavailabilities")
            ]
        else:
            unavailabilities = APIHelper.SKIP
        availabilities = None
        if dictionary.get("Availabilities") is not None:
            availabilities = [
                Availability1.from_dictionary(x)
                    for x in dictionary.get("Availabilities")
            ]
        else:
            availabilities = APIHelper.SKIP
        login_locations = None
        if dictionary.get("LoginLocations") is not None:
            login_locations = [
                Location1.from_dictionary(x)
                    for x in dictionary.get("LoginLocations")
            ]
        else:
            login_locations = APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   first_name,
                   last_name,
                   display_name,
                   email,
                   bio,
                   address,
                   address_2,
                   city,
                   state,
                   postal_code,
                   foreign_zip,
                   country,
                   work_phone,
                   home_phone,
                   cell_phone,
                   active,
                   is_system,
                   smode_id,
                   appointment_trn,
                   always_allow_double_booking,
                   independent_contractor,
                   image_url,
                   is_male,
                   reservation_trn,
                   sort_order,
                   multi_location_permission,
                   name,
                   provider_i_ds,
                   staff_settings,
                   rep,
                   rep_2,
                   rep_3,
                   rep_4,
                   rep_5,
                   rep_6,
                   assistant,
                   assistant_2,
                   employment_start,
                   employment_end,
                   emp_id,
                   appointments,
                   unavailabilities,
                   availabilities,
                   login_locations)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _first_name=(
            self.first_name
            if hasattr(self, "first_name")
            else None
        )
        _last_name=(
            self.last_name
            if hasattr(self, "last_name")
            else None
        )
        _display_name=(
            self.display_name
            if hasattr(self, "display_name")
            else None
        )
        _email=(
            self.email
            if hasattr(self, "email")
            else None
        )
        _bio=(
            self.bio
            if hasattr(self, "bio")
            else None
        )
        _address=(
            self.address
            if hasattr(self, "address")
            else None
        )
        _address_2=(
            self.address_2
            if hasattr(self, "address_2")
            else None
        )
        _city=(
            self.city
            if hasattr(self, "city")
            else None
        )
        _state=(
            self.state
            if hasattr(self, "state")
            else None
        )
        _postal_code=(
            self.postal_code
            if hasattr(self, "postal_code")
            else None
        )
        _foreign_zip=(
            self.foreign_zip
            if hasattr(self, "foreign_zip")
            else None
        )
        _country=(
            self.country
            if hasattr(self, "country")
            else None
        )
        _work_phone=(
            self.work_phone
            if hasattr(self, "work_phone")
            else None
        )
        _home_phone=(
            self.home_phone
            if hasattr(self, "home_phone")
            else None
        )
        _cell_phone=(
            self.cell_phone
            if hasattr(self, "cell_phone")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _is_system=(
            self.is_system
            if hasattr(self, "is_system")
            else None
        )
        _smode_id=(
            self.smode_id
            if hasattr(self, "smode_id")
            else None
        )
        _appointment_trn=(
            self.appointment_trn
            if hasattr(self, "appointment_trn")
            else None
        )
        _always_allow_double_booking=(
            self.always_allow_double_booking
            if hasattr(self, "always_allow_double_booking")
            else None
        )
        _independent_contractor=(
            self.independent_contractor
            if hasattr(self, "independent_contractor")
            else None
        )
        _image_url=(
            self.image_url
            if hasattr(self, "image_url")
            else None
        )
        _is_male=(
            self.is_male
            if hasattr(self, "is_male")
            else None
        )
        _reservation_trn=(
            self.reservation_trn
            if hasattr(self, "reservation_trn")
            else None
        )
        _sort_order=(
            self.sort_order
            if hasattr(self, "sort_order")
            else None
        )
        _multi_location_permission=(
            self.multi_location_permission
            if hasattr(self, "multi_location_permission")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _provider_i_ds=(
            self.provider_i_ds
            if hasattr(self, "provider_i_ds")
            else None
        )
        _staff_settings=(
            self.staff_settings
            if hasattr(self, "staff_settings")
            else None
        )
        _rep=(
            self.rep
            if hasattr(self, "rep")
            else None
        )
        _rep_2=(
            self.rep_2
            if hasattr(self, "rep_2")
            else None
        )
        _rep_3=(
            self.rep_3
            if hasattr(self, "rep_3")
            else None
        )
        _rep_4=(
            self.rep_4
            if hasattr(self, "rep_4")
            else None
        )
        _rep_5=(
            self.rep_5
            if hasattr(self, "rep_5")
            else None
        )
        _rep_6=(
            self.rep_6
            if hasattr(self, "rep_6")
            else None
        )
        _assistant=(
            self.assistant
            if hasattr(self, "assistant")
            else None
        )
        _assistant_2=(
            self.assistant_2
            if hasattr(self, "assistant_2")
            else None
        )
        _employment_start=(
            self.employment_start
            if hasattr(self, "employment_start")
            else None
        )
        _employment_end=(
            self.employment_end
            if hasattr(self, "employment_end")
            else None
        )
        _emp_id=(
            self.emp_id
            if hasattr(self, "emp_id")
            else None
        )
        _appointments=(
            self.appointments
            if hasattr(self, "appointments")
            else None
        )
        _unavailabilities=(
            self.unavailabilities
            if hasattr(self, "unavailabilities")
            else None
        )
        _availabilities=(
            self.availabilities
            if hasattr(self, "availabilities")
            else None
        )
        _login_locations=(
            self.login_locations
            if hasattr(self, "login_locations")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"first_name={_first_name!r}, "
            f"last_name={_last_name!r}, "
            f"display_name={_display_name!r}, "
            f"email={_email!r}, "
            f"bio={_bio!r}, "
            f"address={_address!r}, "
            f"address_2={_address_2!r}, "
            f"city={_city!r}, "
            f"state={_state!r}, "
            f"postal_code={_postal_code!r}, "
            f"foreign_zip={_foreign_zip!r}, "
            f"country={_country!r}, "
            f"work_phone={_work_phone!r}, "
            f"home_phone={_home_phone!r}, "
            f"cell_phone={_cell_phone!r}, "
            f"active={_active!r}, "
            f"is_system={_is_system!r}, "
            f"smode_id={_smode_id!r}, "
            f"appointment_trn={_appointment_trn!r}, "
            f"always_allow_double_booking={_always_allow_double_booking!r}, "
            f"independent_contractor={_independent_contractor!r}, "
            f"image_url={_image_url!r}, "
            f"is_male={_is_male!r}, "
            f"reservation_trn={_reservation_trn!r}, "
            f"sort_order={_sort_order!r}, "
            f"multi_location_permission={_multi_location_permission!r}, "
            f"name={_name!r}, "
            f"provider_i_ds={_provider_i_ds!r}, "
            f"staff_settings={_staff_settings!r}, "
            f"rep={_rep!r}, "
            f"rep_2={_rep_2!r}, "
            f"rep_3={_rep_3!r}, "
            f"rep_4={_rep_4!r}, "
            f"rep_5={_rep_5!r}, "
            f"rep_6={_rep_6!r}, "
            f"assistant={_assistant!r}, "
            f"assistant_2={_assistant_2!r}, "
            f"employment_start={_employment_start!r}, "
            f"employment_end={_employment_end!r}, "
            f"emp_id={_emp_id!r}, "
            f"appointments={_appointments!r}, "
            f"unavailabilities={_unavailabilities!r}, "
            f"availabilities={_availabilities!r}, "
            f"login_locations={_login_locations!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _first_name=(
            self.first_name
            if hasattr(self, "first_name")
            else None
        )
        _last_name=(
            self.last_name
            if hasattr(self, "last_name")
            else None
        )
        _display_name=(
            self.display_name
            if hasattr(self, "display_name")
            else None
        )
        _email=(
            self.email
            if hasattr(self, "email")
            else None
        )
        _bio=(
            self.bio
            if hasattr(self, "bio")
            else None
        )
        _address=(
            self.address
            if hasattr(self, "address")
            else None
        )
        _address_2=(
            self.address_2
            if hasattr(self, "address_2")
            else None
        )
        _city=(
            self.city
            if hasattr(self, "city")
            else None
        )
        _state=(
            self.state
            if hasattr(self, "state")
            else None
        )
        _postal_code=(
            self.postal_code
            if hasattr(self, "postal_code")
            else None
        )
        _foreign_zip=(
            self.foreign_zip
            if hasattr(self, "foreign_zip")
            else None
        )
        _country=(
            self.country
            if hasattr(self, "country")
            else None
        )
        _work_phone=(
            self.work_phone
            if hasattr(self, "work_phone")
            else None
        )
        _home_phone=(
            self.home_phone
            if hasattr(self, "home_phone")
            else None
        )
        _cell_phone=(
            self.cell_phone
            if hasattr(self, "cell_phone")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _is_system=(
            self.is_system
            if hasattr(self, "is_system")
            else None
        )
        _smode_id=(
            self.smode_id
            if hasattr(self, "smode_id")
            else None
        )
        _appointment_trn=(
            self.appointment_trn
            if hasattr(self, "appointment_trn")
            else None
        )
        _always_allow_double_booking=(
            self.always_allow_double_booking
            if hasattr(self, "always_allow_double_booking")
            else None
        )
        _independent_contractor=(
            self.independent_contractor
            if hasattr(self, "independent_contractor")
            else None
        )
        _image_url=(
            self.image_url
            if hasattr(self, "image_url")
            else None
        )
        _is_male=(
            self.is_male
            if hasattr(self, "is_male")
            else None
        )
        _reservation_trn=(
            self.reservation_trn
            if hasattr(self, "reservation_trn")
            else None
        )
        _sort_order=(
            self.sort_order
            if hasattr(self, "sort_order")
            else None
        )
        _multi_location_permission=(
            self.multi_location_permission
            if hasattr(self, "multi_location_permission")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _provider_i_ds=(
            self.provider_i_ds
            if hasattr(self, "provider_i_ds")
            else None
        )
        _staff_settings=(
            self.staff_settings
            if hasattr(self, "staff_settings")
            else None
        )
        _rep=(
            self.rep
            if hasattr(self, "rep")
            else None
        )
        _rep_2=(
            self.rep_2
            if hasattr(self, "rep_2")
            else None
        )
        _rep_3=(
            self.rep_3
            if hasattr(self, "rep_3")
            else None
        )
        _rep_4=(
            self.rep_4
            if hasattr(self, "rep_4")
            else None
        )
        _rep_5=(
            self.rep_5
            if hasattr(self, "rep_5")
            else None
        )
        _rep_6=(
            self.rep_6
            if hasattr(self, "rep_6")
            else None
        )
        _assistant=(
            self.assistant
            if hasattr(self, "assistant")
            else None
        )
        _assistant_2=(
            self.assistant_2
            if hasattr(self, "assistant_2")
            else None
        )
        _employment_start=(
            self.employment_start
            if hasattr(self, "employment_start")
            else None
        )
        _employment_end=(
            self.employment_end
            if hasattr(self, "employment_end")
            else None
        )
        _emp_id=(
            self.emp_id
            if hasattr(self, "emp_id")
            else None
        )
        _appointments=(
            self.appointments
            if hasattr(self, "appointments")
            else None
        )
        _unavailabilities=(
            self.unavailabilities
            if hasattr(self, "unavailabilities")
            else None
        )
        _availabilities=(
            self.availabilities
            if hasattr(self, "availabilities")
            else None
        )
        _login_locations=(
            self.login_locations
            if hasattr(self, "login_locations")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"first_name={_first_name!s}, "
            f"last_name={_last_name!s}, "
            f"display_name={_display_name!s}, "
            f"email={_email!s}, "
            f"bio={_bio!s}, "
            f"address={_address!s}, "
            f"address_2={_address_2!s}, "
            f"city={_city!s}, "
            f"state={_state!s}, "
            f"postal_code={_postal_code!s}, "
            f"foreign_zip={_foreign_zip!s}, "
            f"country={_country!s}, "
            f"work_phone={_work_phone!s}, "
            f"home_phone={_home_phone!s}, "
            f"cell_phone={_cell_phone!s}, "
            f"active={_active!s}, "
            f"is_system={_is_system!s}, "
            f"smode_id={_smode_id!s}, "
            f"appointment_trn={_appointment_trn!s}, "
            f"always_allow_double_booking={_always_allow_double_booking!s}, "
            f"independent_contractor={_independent_contractor!s}, "
            f"image_url={_image_url!s}, "
            f"is_male={_is_male!s}, "
            f"reservation_trn={_reservation_trn!s}, "
            f"sort_order={_sort_order!s}, "
            f"multi_location_permission={_multi_location_permission!s}, "
            f"name={_name!s}, "
            f"provider_i_ds={_provider_i_ds!s}, "
            f"staff_settings={_staff_settings!s}, "
            f"rep={_rep!s}, "
            f"rep_2={_rep_2!s}, "
            f"rep_3={_rep_3!s}, "
            f"rep_4={_rep_4!s}, "
            f"rep_5={_rep_5!s}, "
            f"rep_6={_rep_6!s}, "
            f"assistant={_assistant!s}, "
            f"assistant_2={_assistant_2!s}, "
            f"employment_start={_employment_start!s}, "
            f"employment_end={_employment_end!s}, "
            f"emp_id={_emp_id!s}, "
            f"appointments={_appointments!s}, "
            f"unavailabilities={_unavailabilities!s}, "
            f"availabilities={_availabilities!s}, "
            f"login_locations={_login_locations!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class AssignStaffSessionTypeRequest(object):
    """Implementation of the 'AssignStaffSessionTypeRequest' model.

    Attributes:
        staff_id (int): The ID of the staff member session type is getting assigned
            to. The staff member must be assignable to appointments or already be
            assigned to the session type in the request.
        session_type_id (int): The ID of the session type that is getting assigned to
            the staff member. The session type must be an appointment.
        active (bool): Indicates if assignment is active. Passing `false` is
            equivalent to deleting the assignment.
        time_length (int): The staff specific amount of time that a session of this
            type typically lasts.
        prep_time (int): Prep time in minutes
        finish_time (int): Finish time in minutes
        pay_rate_type (str): The pay rate type. Can be one of the following (case
            insensitive):     Percent     Flat     No Pay     If PayRateType is not
            provided in the request and the request is creating a completely new
            assignment (not editing an existing active or inactive assignment), then
            the staff member default pay rate and pay rate amount are used to create
            the assignment. Otherwise, the existing assignment values are used for
            any optional request parameters not included in the request.
        pay_rate_amount (float): The pay rate amount for the specific staff member.
            It is parsed according to the PayRateType.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "staff_id": "StaffId",
        "session_type_id": "SessionTypeId",
        "active": "Active",
        "time_length": "TimeLength",
        "prep_time": "PrepTime",
        "finish_time": "FinishTime",
        "pay_rate_type": "PayRateType",
        "pay_rate_amount": "PayRateAmount",
    }

    _optionals = [
        "time_length",
        "prep_time",
        "finish_time",
        "pay_rate_type",
        "pay_rate_amount",
    ]

    def __init__(
        self,
        staff_id=None,
        session_type_id=None,
        active=None,
        time_length=APIHelper.SKIP,
        prep_time=APIHelper.SKIP,
        finish_time=APIHelper.SKIP,
        pay_rate_type=APIHelper.SKIP,
        pay_rate_amount=APIHelper.SKIP):
        """Initialize a AssignStaffSessionTypeRequest instance."""
        # Initialize members of the class
        self.staff_id = staff_id
        self.session_type_id = session_type_id
        self.active = active
        if time_length is not APIHelper.SKIP:
            self.time_length = time_length
        if prep_time is not APIHelper.SKIP:
            self.prep_time = prep_time
        if finish_time is not APIHelper.SKIP:
            self.finish_time = finish_time
        if pay_rate_type is not APIHelper.SKIP:
            self.pay_rate_type = pay_rate_type
        if pay_rate_amount is not APIHelper.SKIP:
            self.pay_rate_amount = pay_rate_amount

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else None
        session_type_id =\
            dictionary.get("SessionTypeId")\
            if dictionary.get("SessionTypeId")\
                else None
        active =\
            dictionary.get("Active")\
            if "Active" in dictionary.keys()\
                else None
        time_length =\
            dictionary.get("TimeLength")\
            if dictionary.get("TimeLength")\
                else APIHelper.SKIP
        prep_time =\
            dictionary.get("PrepTime")\
            if dictionary.get("PrepTime")\
                else APIHelper.SKIP
        finish_time =\
            dictionary.get("FinishTime")\
            if dictionary.get("FinishTime")\
                else APIHelper.SKIP
        pay_rate_type =\
            dictionary.get("PayRateType")\
            if dictionary.get("PayRateType")\
                else APIHelper.SKIP
        pay_rate_amount =\
            dictionary.get("PayRateAmount")\
            if dictionary.get("PayRateAmount")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(staff_id,
                   session_type_id,
                   active,
                   time_length,
                   prep_time,
                   finish_time,
                   pay_rate_type,
                   pay_rate_amount)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _staff_id=self.staff_id
        _session_type_id=self.session_type_id
        _active=self.active
        _time_length=(
            self.time_length
            if hasattr(self, "time_length")
            else None
        )
        _prep_time=(
            self.prep_time
            if hasattr(self, "prep_time")
            else None
        )
        _finish_time=(
            self.finish_time
            if hasattr(self, "finish_time")
            else None
        )
        _pay_rate_type=(
            self.pay_rate_type
            if hasattr(self, "pay_rate_type")
            else None
        )
        _pay_rate_amount=(
            self.pay_rate_amount
            if hasattr(self, "pay_rate_amount")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!r}, "
            f"session_type_id={_session_type_id!r}, "
            f"active={_active!r}, "
            f"time_length={_time_length!r}, "
            f"prep_time={_prep_time!r}, "
            f"finish_time={_finish_time!r}, "
            f"pay_rate_type={_pay_rate_type!r}, "
            f"pay_rate_amount={_pay_rate_amount!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _staff_id=self.staff_id
        _session_type_id=self.session_type_id
        _active=self.active
        _time_length=(
            self.time_length
            if hasattr(self, "time_length")
            else None
        )
        _prep_time=(
            self.prep_time
            if hasattr(self, "prep_time")
            else None
        )
        _finish_time=(
            self.finish_time
            if hasattr(self, "finish_time")
            else None
        )
        _pay_rate_type=(
            self.pay_rate_type
            if hasattr(self, "pay_rate_type")
            else None
        )
        _pay_rate_amount=(
            self.pay_rate_amount
            if hasattr(self, "pay_rate_amount")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!s}, "
            f"session_type_id={_session_type_id!s}, "
            f"active={_active!s}, "
            f"time_length={_time_length!s}, "
            f"prep_time={_prep_time!s}, "
            f"finish_time={_finish_time!s}, "
            f"pay_rate_type={_pay_rate_type!s}, "
            f"pay_rate_amount={_pay_rate_amount!s}, "
            f")"
        )
